diff -Nur kernel/0001-bpf-bpftool-add-support-for-attaching-programs-to-ma.patch obs_kernel/0001-bpf-bpftool-add-support-for-attaching-programs-to-ma.patch
--- kernel/0001-bpf-bpftool-add-support-for-attaching-programs-to-ma.patch	1970-01-01 08:00:00.000000000 +0800
+++ obs_kernel/0001-bpf-bpftool-add-support-for-attaching-programs-to-ma.patch	2022-10-22 10:42:24.000000000 +0800
@@ -0,0 +1,251 @@
+From 9abe1b09e367fb4dc9577cf5a21b61efb86a16d6 Mon Sep 17 00:00:00 2001
+From: John Fastabend <john.fastabend@gmail.com>
+Date: Mon, 15 Oct 2018 11:19:50 -0700
+Subject: [PATCH] bpf: bpftool, add support for attaching programs to maps
+
+Sock map/hash introduce support for attaching programs to maps. To
+date I have been doing this with custom tooling but this is less than
+ideal as we shift to using bpftool as the single CLI for our BPF uses.
+This patch adds new sub commands 'attach' and 'detach' to the 'prog'
+command to attach programs to maps and then detach them.
+
+Signed-off-by: John Fastabend <john.fastabend@gmail.com>
+Reviewed-by: Jakub Kicinski <jakub.kicinski@netronome.com>
+Signed-off-by: Alexei Starovoitov <ast@kernel.org>
+---
+ .../bpftool/Documentation/bpftool-prog.rst    | 11 +++
+ tools/bpf/bpftool/Documentation/bpftool.rst   |  2 +-
+ tools/bpf/bpftool/bash-completion/bpftool     | 19 +++-
+ tools/bpf/bpftool/prog.c                      | 99 ++++++++++++++++++-
+ 4 files changed, 128 insertions(+), 3 deletions(-)
+
+diff --git a/tools/bpf/bpftool/Documentation/bpftool-prog.rst b/tools/bpf/bpftool/Documentation/bpftool-prog.rst
+index 64156a16d530..12c803003ab2 100644
+--- a/tools/bpf/bpftool/Documentation/bpftool-prog.rst
++++ b/tools/bpf/bpftool/Documentation/bpftool-prog.rst
+@@ -25,6 +25,8 @@ MAP COMMANDS
+ |	**bpftool** **prog dump jited**  *PROG* [{**file** *FILE* | **opcodes**}]
+ |	**bpftool** **prog pin** *PROG* *FILE*
+ |	**bpftool** **prog load** *OBJ* *FILE* [**type** *TYPE*] [**map** {**idx** *IDX* | **name** *NAME*} *MAP*] [**dev** *NAME*]
++|       **bpftool** **prog attach** *PROG* *ATTACH_TYPE* *MAP*
++|       **bpftool** **prog detach** *PROG* *ATTACH_TYPE* *MAP*
+ |	**bpftool** **prog help**
+ |
+ |	*MAP* := { **id** *MAP_ID* | **pinned** *FILE* }
+@@ -37,6 +39,7 @@ MAP COMMANDS
+ |		**cgroup/bind4** | **cgroup/bind6** | **cgroup/post_bind4** | **cgroup/post_bind6** |
+ |		**cgroup/connect4** | **cgroup/connect6** | **cgroup/sendmsg4** | **cgroup/sendmsg6**
+ |	}
++|       *ATTACH_TYPE* := { **msg_verdict** | **skb_verdict** | **skb_parse** }
+ 
+ 
+ DESCRIPTION
+@@ -90,6 +93,14 @@ DESCRIPTION
+ 
+ 		  Note: *FILE* must be located in *bpffs* mount.
+ 
++        **bpftool prog attach** *PROG* *ATTACH_TYPE* *MAP*
++                  Attach bpf program *PROG* (with type specified by *ATTACH_TYPE*)
++                  to the map *MAP*.
++
++        **bpftool prog detach** *PROG* *ATTACH_TYPE* *MAP*
++                  Detach bpf program *PROG* (with type specified by *ATTACH_TYPE*)
++                  from the map *MAP*.
++
+ 	**bpftool prog help**
+ 		  Print short help message.
+ 
+diff --git a/tools/bpf/bpftool/Documentation/bpftool.rst b/tools/bpf/bpftool/Documentation/bpftool.rst
+index b6f5d560460d..326a7f90f02f 100644
+--- a/tools/bpf/bpftool/Documentation/bpftool.rst
++++ b/tools/bpf/bpftool/Documentation/bpftool.rst
+@@ -26,7 +26,7 @@ SYNOPSIS
+ 	| **pin** | **event_pipe** | **help** }
+ 
+ 	*PROG-COMMANDS* := { **show** | **list** | **dump jited** | **dump xlated** | **pin**
+-	| **load** | **help** }
++	| **load** | **attach** | **detach** | **help** }
+ 
+ 	*CGROUP-COMMANDS* := { **show** | **list** | **attach** | **detach** | **help** }
+ 
+diff --git a/tools/bpf/bpftool/bash-completion/bpftool b/tools/bpf/bpftool/bash-completion/bpftool
+index c2b6b2176f3b..845d8112d59d 100644
+--- a/tools/bpf/bpftool/bash-completion/bpftool
++++ b/tools/bpf/bpftool/bash-completion/bpftool
+@@ -292,6 +292,23 @@ _bpftool()
+                     fi
+                     return 0
+                     ;;
++                attach|detach)
++                    if [[ ${#words[@]} == 7 ]]; then
++                        COMPREPLY=( $( compgen -W "id pinned" -- "$cur" ) )
++                        return 0
++                    fi
++
++                    if [[ ${#words[@]} == 6 ]]; then
++                        COMPREPLY=( $( compgen -W "msg_verdict skb_verdict skb_parse" -- "$cur" ) )
++                        return 0
++                    fi
++
++                    if [[ $prev == "$command" ]]; then
++                        COMPREPLY=( $( compgen -W "id pinned" -- "$cur" ) )
++                        return 0
++                    fi
++                    return 0
++                    ;;
+                 load)
+                     local obj
+ 
+@@ -347,7 +364,7 @@ _bpftool()
+                     ;;
+                 *)
+                     [[ $prev == $object ]] && \
+-                        COMPREPLY=( $( compgen -W 'dump help pin load \
++                        COMPREPLY=( $( compgen -W 'dump help pin attach detach load \
+                             show list' -- "$cur" ) )
+                     ;;
+             esac
+diff --git a/tools/bpf/bpftool/prog.c b/tools/bpf/bpftool/prog.c
+index 522e08ab3a86..4362297ce77f 100644
+--- a/tools/bpf/bpftool/prog.c
++++ b/tools/bpf/bpftool/prog.c
+@@ -77,6 +77,26 @@ static const char * const prog_type_name[] = {
+ 	[BPF_PROG_TYPE_LIRC_MODE2]	= "lirc_mode2",
+ };
+ 
++static const char * const attach_type_strings[] = {
++	[BPF_SK_SKB_STREAM_PARSER] = "stream_parser",
++	[BPF_SK_SKB_STREAM_VERDICT] = "stream_verdict",
++	[BPF_SK_MSG_VERDICT] = "msg_verdict",
++	[__MAX_BPF_ATTACH_TYPE] = NULL,
++};
++
++enum bpf_attach_type parse_attach_type(const char *str)
++{
++	enum bpf_attach_type type;
++
++	for (type = 0; type < __MAX_BPF_ATTACH_TYPE; type++) {
++		if (attach_type_strings[type] &&
++		    is_prefix(str, attach_type_strings[type]))
++			return type;
++	}
++
++	return __MAX_BPF_ATTACH_TYPE;
++}
++
+ static void print_boot_time(__u64 nsecs, char *buf, unsigned int size)
+ {
+ 	struct timespec real_time_ts, boot_time_ts;
+@@ -700,6 +720,77 @@ int map_replace_compar(const void *p1, const void *p2)
+ 	return a->idx - b->idx;
+ }
+ 
++static int do_attach(int argc, char **argv)
++{
++	enum bpf_attach_type attach_type;
++	int err, mapfd, progfd;
++
++	if (!REQ_ARGS(5)) {
++		p_err("too few parameters for map attach");
++		return -EINVAL;
++	}
++
++	progfd = prog_parse_fd(&argc, &argv);
++	if (progfd < 0)
++		return progfd;
++
++	attach_type = parse_attach_type(*argv);
++	if (attach_type == __MAX_BPF_ATTACH_TYPE) {
++		p_err("invalid attach type");
++		return -EINVAL;
++	}
++	NEXT_ARG();
++
++	mapfd = map_parse_fd(&argc, &argv);
++	if (mapfd < 0)
++		return mapfd;
++
++	err = bpf_prog_attach(progfd, mapfd, attach_type, 0);
++	if (err) {
++		p_err("failed prog attach to map");
++		return -EINVAL;
++	}
++
++	if (json_output)
++		jsonw_null(json_wtr);
++	return 0;
++}
++
++static int do_detach(int argc, char **argv)
++{
++	enum bpf_attach_type attach_type;
++	int err, mapfd, progfd;
++
++	if (!REQ_ARGS(5)) {
++		p_err("too few parameters for map detach");
++		return -EINVAL;
++	}
++
++	progfd = prog_parse_fd(&argc, &argv);
++	if (progfd < 0)
++		return progfd;
++
++	attach_type = parse_attach_type(*argv);
++	if (attach_type == __MAX_BPF_ATTACH_TYPE) {
++		p_err("invalid attach type");
++		return -EINVAL;
++	}
++	NEXT_ARG();
++
++	mapfd = map_parse_fd(&argc, &argv);
++	if (mapfd < 0)
++		return mapfd;
++
++	err = bpf_prog_detach2(progfd, mapfd, attach_type);
++	if (err) {
++		p_err("failed prog detach from map");
++		return -EINVAL;
++	}
++
++	if (json_output)
++		jsonw_null(json_wtr);
++	return 0;
++}
+ static int do_load(int argc, char **argv)
+ {
+ 	enum bpf_attach_type expected_attach_type;
+@@ -949,6 +1040,8 @@ static int do_help(int argc, char **argv)
+ 		"       %s %s pin   PROG FILE\n"
+ 		"       %s %s load  OBJ  FILE [type TYPE] [dev NAME] \\\n"
+ 		"                         [map { idx IDX | name NAME } MAP]\n"
++		"       %s %s attach PROG ATTACH_TYPE MAP\n"
++		"       %s %s detach PROG ATTACH_TYPE MAP\n"
+ 		"       %s %s help\n"
+ 		"\n"
+ 		"       " HELP_SPEC_MAP "\n"
+@@ -960,10 +1053,12 @@ static int do_help(int argc, char **argv)
+ 		"                 cgroup/bind4 | cgroup/bind6 | cgroup/post_bind4 |\n"
+ 		"                 cgroup/post_bind6 | cgroup/connect4 | cgroup/connect6 |\n"
+ 		"                 cgroup/sendmsg4 | cgroup/sendmsg6 }\n"
++		"       ATTACH_TYPE := { msg_verdict | skb_verdict | skb_parse }\n"
+ 		"       " HELP_SPEC_OPTIONS "\n"
+ 		"",
+ 		bin_name, argv[-2], bin_name, argv[-2], bin_name, argv[-2],
+-		bin_name, argv[-2], bin_name, argv[-2], bin_name, argv[-2]);
++		bin_name, argv[-2], bin_name, argv[-2], bin_name, argv[-2],
++		bin_name, argv[-2], bin_name, argv[-2]);
+ 
+ 	return 0;
+ }
+@@ -975,6 +1070,8 @@ static const struct cmd cmds[] = {
+ 	{ "dump",	do_dump },
+ 	{ "pin",	do_pin },
+ 	{ "load",	do_load },
++	{ "attach",	do_attach },
++	{ "detach",	do_detach },
+ 	{ 0 }
+ };
+ 
+-- 
+2.27.0
+
diff -Nur kernel/0001-disable-some-kconfig-for-unixbench.patch obs_kernel/0001-disable-some-kconfig-for-unixbench.patch
--- kernel/0001-disable-some-kconfig-for-unixbench.patch	1970-01-01 08:00:00.000000000 +0800
+++ obs_kernel/0001-disable-some-kconfig-for-unixbench.patch	2022-10-25 01:12:22.000000000 +0800
@@ -0,0 +1,1079 @@
+From 34625002352da11b9eb6395af571231a55b9ca7a Mon Sep 17 00:00:00 2001
+From: hongrongxuan <hongrongxuan@huawei.com>
+Date: Tue, 25 Oct 2022 01:10:37 +0800
+Subject: [PATCH] init
+
+---
+ arch/arm64/configs/openeuler_defconfig | 151 ++++++++++++++++---------
+ arch/x86/configs/openeuler_defconfig   | 137 +++++++++++-----------
+ 2 files changed, 162 insertions(+), 126 deletions(-)
+
+diff --git a/arch/arm64/configs/openeuler_defconfig b/arch/arm64/configs/openeuler_defconfig
+index 4bdd64ae6..d7d6ee62a 100644
+--- a/arch/arm64/configs/openeuler_defconfig
++++ b/arch/arm64/configs/openeuler_defconfig
+@@ -1,17 +1,17 @@
+ #
+ # Automatically generated file; DO NOT EDIT.
+-# Linux/arm64 4.19.93 Kernel Configuration
++# Linux/arm64 4.19.90 Kernel Configuration
+ #
+ 
+ #
+-# Compiler: gcc_old (GCC) 7.3.0
++# Compiler: gcc (GCC) 7.3.0
+ #
+ CONFIG_CC_IS_GCC=y
+ CONFIG_GCC_VERSION=70300
+ CONFIG_CLANG_VERSION=0
+ CONFIG_CC_HAS_ASM_GOTO=y
+ CONFIG_IRQ_WORK=y
+-CONFIG_BUILDTIME_EXTABLE_SORT=y
++CONFIG_BUILDTIME_TABLE_SORT=y
+ CONFIG_THREAD_INFO_IN_TASK=y
+ 
+ #
+@@ -30,11 +30,8 @@ CONFIG_POSIX_MQUEUE=y
+ CONFIG_POSIX_MQUEUE_SYSCTL=y
+ CONFIG_CROSS_MEMORY_ATTACH=y
+ # CONFIG_USELIB is not set
+-CONFIG_AUDIT=y
++# CONFIG_AUDIT is not set
+ CONFIG_HAVE_ARCH_AUDITSYSCALL=y
+-CONFIG_AUDITSYSCALL=y
+-CONFIG_AUDIT_WATCH=y
+-CONFIG_AUDIT_TREE=y
+ # CONFIG_KTASK is not set
+ 
+ #
+@@ -45,6 +42,7 @@ CONFIG_GENERIC_IRQ_SHOW=y
+ CONFIG_GENERIC_IRQ_SHOW_LEVEL=y
+ CONFIG_GENERIC_IRQ_EFFECTIVE_AFF_MASK=y
+ CONFIG_GENERIC_IRQ_MIGRATION=y
++CONFIG_GENERIC_IRQ_INJECTION=y
+ CONFIG_HARDIRQS_SW_RESEND=y
+ CONFIG_GENERIC_IRQ_CHIP=y
+ CONFIG_IRQ_DOMAIN=y
+@@ -137,15 +135,15 @@ CONFIG_CGROUP_PERF=y
+ CONFIG_CGROUP_BPF=y
+ # CONFIG_CGROUP_DEBUG is not set
+ CONFIG_SOCK_CGROUP_DATA=y
+-CONFIG_CGROUP_FILES=y
++# CONFIG_CGROUP_FILES is not set
+ CONFIG_NAMESPACES=y
+ CONFIG_UTS_NS=y
+ CONFIG_IPC_NS=y
+ CONFIG_USER_NS=y
+ CONFIG_PID_NS=y
+ CONFIG_NET_NS=y
+-CONFIG_CHECKPOINT_RESTORE=y
+ CONFIG_SCHED_STEAL=y
++CONFIG_CHECKPOINT_RESTORE=y
+ CONFIG_SCHED_AUTOGROUP=y
+ # CONFIG_SYSFS_DEPRECATED is not set
+ CONFIG_RELAY=y
+@@ -179,12 +177,14 @@ CONFIG_ELF_CORE=y
+ CONFIG_BASE_FULL=y
+ CONFIG_FUTEX=y
+ CONFIG_FUTEX_PI=y
++CONFIG_HAVE_FUTEX_CMPXCHG=y
+ CONFIG_EPOLL=y
+ CONFIG_SIGNALFD=y
+ CONFIG_TIMERFD=y
+ CONFIG_EVENTFD=y
+ CONFIG_SHMEM=y
+ CONFIG_AIO=y
++CONFIG_IO_URING=y
+ CONFIG_ADVISE_SYSCALLS=y
+ CONFIG_MEMBARRIER=y
+ CONFIG_KALLSYMS=y
+@@ -248,6 +248,7 @@ CONFIG_FIX_EARLYCON_MEM=y
+ CONFIG_PGTABLE_LEVELS=3
+ CONFIG_ARCH_SUPPORTS_UPROBES=y
+ CONFIG_ARCH_PROC_KCORE_TEXT=y
++CONFIG_ARCH_HAS_CPU_RELAX=y
+ 
+ #
+ # Platform selection
+@@ -401,6 +402,7 @@ CONFIG_QCOM_FALKOR_ERRATUM_1009=y
+ CONFIG_QCOM_QDF2400_ERRATUM_0065=y
+ CONFIG_SOCIONEXT_SYNQUACER_PREITS=y
+ CONFIG_HISILICON_ERRATUM_161600802=y
++# CONFIG_HISILICON_ERRATUM_1980005 is not set
+ CONFIG_QCOM_FALKOR_ERRATUM_E1041=y
+ CONFIG_HISILICON_ERRATUM_HIP08_RU_PREFETCH=y
+ # CONFIG_HISILICON_HIP08_RU_PREFETCH_DEFAULT_OFF is not set
+@@ -418,8 +420,9 @@ CONFIG_SCHED_MC=y
+ # CONFIG_SCHED_SMT is not set
+ CONFIG_NR_CPUS=1024
+ CONFIG_HOTPLUG_CPU=y
++# CONFIG_ARM64_BOOTPARAM_HOTPLUG_CPU0 is not set
+ CONFIG_ARM64_ERR_RECOV=y
+-CONFIG_MPAM=y
++# CONFIG_MPAM is not set
+ CONFIG_NUMA=y
+ CONFIG_NODES_SHIFT=4
+ # CONFIG_NUMA_AWARE_SPINLOCKS is not set
+@@ -477,6 +480,7 @@ CONFIG_ARM64_MODULE_PLTS=y
+ CONFIG_RELOCATABLE=y
+ CONFIG_RANDOMIZE_BASE=y
+ CONFIG_RANDOMIZE_MODULE_REGION_FULL=y
++# CONFIG_ASCEND_FEATURES is not set
+ 
+ #
+ # Boot options
+@@ -492,11 +496,6 @@ CONFIG_AARCH32_EL0=y
+ # CONFIG_ARM64_ILP32 is not set
+ CONFIG_SYSVIPC_COMPAT=y
+ 
+-#
+-# TLB options
+-#
+-CONFIG_ARM64_TLBI_IPI=y
+-
+ #
+ # Power management options
+ #
+@@ -525,6 +524,12 @@ CONFIG_CPU_PM=y
+ CONFIG_ARCH_HIBERNATION_POSSIBLE=y
+ CONFIG_ARCH_HIBERNATION_HEADER=y
+ CONFIG_ARCH_SUSPEND_POSSIBLE=y
++# CONFIG_UCE_KERNEL_RECOVERY is not set
++
++#
++# TLB options
++#
++# CONFIG_ARM64_TLBI_IPI is not set
+ 
+ #
+ # CPU Power Management
+@@ -534,9 +539,11 @@ CONFIG_ARCH_SUSPEND_POSSIBLE=y
+ # CPU Idle
+ #
+ CONFIG_CPU_IDLE=y
++CONFIG_CPU_IDLE_MULTIPLE_DRIVERS=y
+ # CONFIG_CPU_IDLE_GOV_LADDER is not set
+ CONFIG_CPU_IDLE_GOV_MENU=y
+ CONFIG_CPU_IDLE_GOV_HALTPOLL=y
++CONFIG_DT_IDLE_STATES=y
+ 
+ #
+ # ARM CPU Idle Drivers
+@@ -594,13 +601,12 @@ CONFIG_HAVE_ARM_SMCCC=y
+ #
+ # EFI (Extensible Firmware Interface) Support
+ #
+-#CONFIG_EFI_VARS is not set
++# CONFIG_EFI_VARS is not set
+ CONFIG_EFI_ESRT=y
+ CONFIG_EFI_PARAMS_FROM_FDT=y
+ CONFIG_EFI_RUNTIME_WRAPPERS=y
+ CONFIG_EFI_ARMSTUB=y
+ CONFIG_EFI_ARMSTUB_DTB_LOADER=y
+-# CONFIG_EFI_BOOTLOADER_CONTROL is not set
+ # CONFIG_EFI_CAPSULE_LOADER is not set
+ # CONFIG_EFI_TEST is not set
+ # CONFIG_RESET_ATTACK_MITIGATION is not set
+@@ -745,6 +751,7 @@ CONFIG_HAVE_VIRT_CPU_ACCOUNTING_GEN=y
+ CONFIG_HAVE_IRQ_TIME_ACCOUNTING=y
+ CONFIG_HAVE_ARCH_TRANSPARENT_HUGEPAGE=y
+ CONFIG_HAVE_ARCH_HUGE_VMAP=y
++CONFIG_HAVE_ARCH_HUGE_VMALLOC=y
+ CONFIG_HAVE_MOD_ARCH_SPECIFIC=y
+ CONFIG_MODULES_USE_ELF_RELA=y
+ CONFIG_ARCH_HAS_ELF_RANDOMIZE=y
+@@ -772,7 +779,6 @@ CONFIG_HAVE_ARCH_PREL32_RELOCATIONS=y
+ CONFIG_ARCH_HAS_GCOV_PROFILE_ALL=y
+ CONFIG_PLUGIN_HOSTCC=""
+ CONFIG_HAVE_GCC_PLUGINS=y
+-# CONFIG_GCC_PLUGINS is not set
+ CONFIG_RT_MUTEXES=y
+ CONFIG_BASE_SMALL=0
+ CONFIG_MODULES=y
+@@ -922,7 +928,6 @@ CONFIG_FREEZER=y
+ # Executable file formats
+ #
+ CONFIG_BINFMT_ELF=y
+-CONFIG_COMPAT_BINFMT_ELF=y
+ CONFIG_ELFCORE=y
+ CONFIG_CORE_DUMP_DEFAULT_ELF_HEADERS=y
+ CONFIG_BINFMT_SCRIPT=y
+@@ -955,6 +960,7 @@ CONFIG_BALLOON_COMPACTION=y
+ CONFIG_COMPACTION=y
+ CONFIG_MIGRATION=y
+ CONFIG_PHYS_ADDR_T_64BIT=y
++CONFIG_MM_OWNER=y
+ CONFIG_MMU_NOTIFIER=y
+ CONFIG_KSM=y
+ CONFIG_DEFAULT_MMAP_MIN_ADDR=4096
+@@ -969,6 +975,7 @@ CONFIG_CLEANCACHE=y
+ CONFIG_FRONTSWAP=y
+ CONFIG_SHRINK_PAGECACHE=y
+ CONFIG_USERSWAP=y
++CONFIG_MEMCG_QOS=y
+ CONFIG_CMA=y
+ # CONFIG_CMA_DEBUG is not set
+ # CONFIG_CMA_DEBUGFS is not set
+@@ -1000,6 +1007,7 @@ CONFIG_NET_EGRESS=y
+ CONFIG_PACKET=y
+ CONFIG_PACKET_DIAG=m
+ CONFIG_UNIX=y
++CONFIG_UNIX_SCM=y
+ CONFIG_UNIX_DIAG=m
+ CONFIG_TLS=m
+ CONFIG_TLS_DEVICE=y
+@@ -1210,7 +1218,6 @@ CONFIG_NETFILTER_XT_SET=m
+ #
+ # Xtables targets
+ #
+-CONFIG_NETFILTER_XT_TARGET_AUDIT=m
+ CONFIG_NETFILTER_XT_TARGET_CHECKSUM=m
+ CONFIG_NETFILTER_XT_TARGET_CLASSIFY=m
+ CONFIG_NETFILTER_XT_TARGET_CONNMARK=m
+@@ -1701,7 +1708,7 @@ CONFIG_CAN_PEAK_USB=m
+ # CONFIG_BT is not set
+ # CONFIG_AF_RXRPC is not set
+ # CONFIG_AF_KCM is not set
+-CONFIG_STREAM_PARSER=m
++CONFIG_STREAM_PARSER=y
+ CONFIG_FIB_RULES=y
+ CONFIG_WIRELESS=y
+ CONFIG_WEXT_CORE=y
+@@ -1913,6 +1920,7 @@ CONFIG_MTD_SPI_NOR=m
+ CONFIG_MTD_MT81xx_NOR=m
+ CONFIG_MTD_SPI_NOR_USE_4K_SECTORS=y
+ # CONFIG_SPI_CADENCE_QUADSPI is not set
++# CONFIG_SPI_HISI_SFC is not set
+ CONFIG_MTD_UBI=m
+ CONFIG_MTD_UBI_WL_THRESHOLD=4096
+ CONFIG_MTD_UBI_BEB_LIMIT=20
+@@ -2073,6 +2081,7 @@ CONFIG_ALTERA_STAPL=m
+ # CONFIG_ECHO is not set
+ # CONFIG_MISC_RTSX_PCI is not set
+ # CONFIG_MISC_RTSX_USB is not set
++# CONFIG_UACCE is not set
+ 
+ #
+ # SCSI device support
+@@ -2165,10 +2174,10 @@ CONFIG_SCSI_QLA_FC=m
+ CONFIG_SCSI_QLA_ISCSI=m
+ CONFIG_QEDI=m
+ CONFIG_QEDF=m
+-CONFIG_SCSI_LPFC=m
+-# CONFIG_SCSI_LPFC_DEBUG_FS is not set
+ CONFIG_SCSI_HUAWEI_FC=m
+ CONFIG_SCSI_FC_HIFC=m
++CONFIG_SCSI_LPFC=m
++# CONFIG_SCSI_LPFC_DEBUG_FS is not set
+ # CONFIG_SCSI_DC395x is not set
+ # CONFIG_SCSI_AM53C974 is not set
+ # CONFIG_SCSI_WD719X is not set
+@@ -2229,6 +2238,7 @@ CONFIG_ATA_PIIX=m
+ # CONFIG_SATA_ULI is not set
+ # CONFIG_SATA_VIA is not set
+ # CONFIG_SATA_VITESSE is not set
++# CONFIG_SATA_ZHAOXIN is not set
+ 
+ #
+ # PATA SFF controllers with BMDMA
+@@ -2472,8 +2482,6 @@ CONFIG_HNS3_CAE=m
+ CONFIG_NET_VENDOR_HUAWEI=y
+ CONFIG_HINIC=m
+ CONFIG_BMA=m
+-CONFIG_NET_VENDOR_NETSWIFT=y
+-CONFIG_TXGBE=m
+ # CONFIG_NET_VENDOR_I825XX is not set
+ CONFIG_NET_VENDOR_INTEL=y
+ # CONFIG_E100 is not set
+@@ -2492,6 +2500,9 @@ CONFIG_I40E=m
+ CONFIG_I40EVF=m
+ CONFIG_ICE=m
+ CONFIG_FM10K=m
++CONFIG_NET_VENDOR_NETSWIFT=y
++CONFIG_TXGBE=m
++# CONFIG_NGBE is not set
+ # CONFIG_JME is not set
+ # CONFIG_NET_VENDOR_MARVELL is not set
+ CONFIG_NET_VENDOR_MELLANOX=y
+@@ -3037,6 +3048,7 @@ CONFIG_HW_RANDOM=y
+ CONFIG_HW_RANDOM_TIMERIOMEM=m
+ CONFIG_HW_RANDOM_VIRTIO=m
+ CONFIG_HW_RANDOM_HISI=y
++CONFIG_HW_RANDOM_HISI_V2=y
+ CONFIG_HW_RANDOM_XGENE=y
+ CONFIG_HW_RANDOM_CAVIUM=y
+ # CONFIG_APPLICOM is not set
+@@ -3206,6 +3218,7 @@ CONFIG_SPI_XLP=m
+ # CONFIG_SPI_LOOPBACK_TEST is not set
+ # CONFIG_SPI_TLE62X0 is not set
+ # CONFIG_SPI_SLAVE is not set
++CONFIG_SPI_DYNAMIC=y
+ # CONFIG_SPMI is not set
+ # CONFIG_HSI is not set
+ CONFIG_PPS=y
+@@ -3742,7 +3755,6 @@ CONFIG_USB_VIDEO_CLASS_INPUT_EVDEV=y
+ # CONFIG_USB_GSPCA is not set
+ # CONFIG_USB_PWC is not set
+ # CONFIG_VIDEO_CPIA2 is not set
+-# CONFIG_USB_ZR364XX is not set
+ # CONFIG_USB_STKWEBCAM is not set
+ # CONFIG_USB_S2255 is not set
+ 
+@@ -4663,7 +4675,6 @@ CONFIG_INFINIBAND_HNS_HIP08=m
+ CONFIG_INFINIBAND_IPOIB=m
+ CONFIG_INFINIBAND_IPOIB_CM=y
+ # CONFIG_INFINIBAND_IPOIB_DEBUG is not set
+-# CONFIG_INFINIBAND_IPOIB_DEBUG_DATA is not set
+ CONFIG_INFINIBAND_SRP=m
+ CONFIG_INFINIBAND_SRPT=m
+ CONFIG_INFINIBAND_ISER=m
+@@ -4877,7 +4888,58 @@ CONFIG_VIRTIO_MMIO=m
+ #
+ # Microsoft Hyper-V guest support
+ #
+-# CONFIG_STAGING is not set
++CONFIG_STAGING=y
++# CONFIG_PRISM2_USB is not set
++# CONFIG_COMEDI is not set
++# CONFIG_RTL8192U is not set
++# CONFIG_RTLLIB is not set
++# CONFIG_RTL8723BS is not set
++# CONFIG_R8712U is not set
++# CONFIG_R8188EU is not set
++# CONFIG_R8822BE is not set
++# CONFIG_RTS5208 is not set
++# CONFIG_VT6655 is not set
++# CONFIG_VT6656 is not set
++# CONFIG_FB_SM750 is not set
++# CONFIG_FB_XGI is not set
++
++#
++# Speakup console speech
++#
++# CONFIG_SPEAKUP is not set
++# CONFIG_STAGING_MEDIA is not set
++
++#
++# Android
++#
++# CONFIG_STAGING_BOARD is not set
++# CONFIG_LTE_GDM724X is not set
++# CONFIG_DGNC is not set
++# CONFIG_GS_FPGABOOT is not set
++# CONFIG_UNISYSSPAR is not set
++# CONFIG_COMMON_CLK_XLNX_CLKWZRD is not set
++# CONFIG_FB_TFT is not set
++# CONFIG_WILC1000_SDIO is not set
++# CONFIG_WILC1000_SPI is not set
++# CONFIG_MOST is not set
++# CONFIG_KS7010 is not set
++# CONFIG_GREYBUS is not set
++# CONFIG_PI433 is not set
++# CONFIG_MTK_MMC is not set
++
++#
++# Gasket devices
++#
++# CONFIG_STAGING_GASKET_FRAMEWORK is not set
++# CONFIG_XIL_AXIS_FIFO is not set
++# CONFIG_EROFS_FS is not set
++
++#
++# GMJS TCM support
++#
++CONFIG_GMJS_TCM=y
++CONFIG_GMJS_TCM_CORE=m
++CONFIG_GMJS_TCM_SPI=m
+ # CONFIG_GOLDFISH is not set
+ CONFIG_CHROME_PLATFORMS=y
+ # CONFIG_CHROMEOS_TBMC is not set
+@@ -4968,6 +5030,7 @@ CONFIG_IOMMU_PAGE_FAULT=y
+ CONFIG_ARM_SMMU=y
+ CONFIG_ARM_SMMU_V3=y
+ # CONFIG_QCOM_IOMMU is not set
++CONFIG_SMMU_BYPASS_DEV=y
+ 
+ #
+ # Remoteproc drivers
+@@ -5099,11 +5162,11 @@ CONFIG_ARM_PMU=y
+ CONFIG_ARM_PMU_ACPI=y
+ CONFIG_ARM_SMMU_V3_PMU=y
+ # CONFIG_ARM_DSU_PMU is not set
+-CONFIG_HISI_PMU=m
+ CONFIG_QCOM_L2_PMU=y
+ CONFIG_QCOM_L3_PMU=y
+ CONFIG_XGENE_PMU=y
+ CONFIG_ARM_SPE_PMU=y
++CONFIG_HISI_PMU=m
+ CONFIG_RAS=y
+ 
+ #
+@@ -5138,7 +5201,6 @@ CONFIG_TEE=m
+ #
+ # CONFIG_OPTEE is not set
+ # CONFIG_SIOX is not set
+-# CONFIG_UACCE is not set
+ # CONFIG_SLIMBUS is not set
+ 
+ #
+@@ -5248,6 +5310,7 @@ CONFIG_SYSFS=y
+ CONFIG_TMPFS=y
+ CONFIG_TMPFS_POSIX_ACL=y
+ CONFIG_TMPFS_XATTR=y
++# CONFIG_TMPFS_INODE64 is not set
+ CONFIG_HUGETLBFS=y
+ CONFIG_HUGETLB_PAGE=y
+ CONFIG_MEMFD_CREATE=y
+@@ -5422,7 +5485,7 @@ CONFIG_NLS_MAC_ROMANIAN=m
+ CONFIG_NLS_MAC_TURKISH=m
+ CONFIG_NLS_UTF8=m
+ # CONFIG_DLM is not set
+-CONFIG_RESCTRL=y
++CONFIG_IO_WQ=y
+ 
+ #
+ # Security options
+@@ -5436,35 +5499,25 @@ CONFIG_ENCRYPTED_KEYS=m
+ # CONFIG_KEY_DH_OPERATIONS is not set
+ # CONFIG_SECURITY_DMESG_RESTRICT is not set
+ CONFIG_SECURITY=y
+-CONFIG_SECURITY_WRITABLE_HOOKS=y
+ CONFIG_SECURITYFS=y
+ CONFIG_SECURITY_NETWORK=y
+ CONFIG_SECURITY_INFINIBAND=y
+ CONFIG_SECURITY_NETWORK_XFRM=y
+ CONFIG_SECURITY_PATH=y
+-CONFIG_LSM_MMAP_MIN_ADDR=65535
+ CONFIG_HAVE_HARDENED_USERCOPY_ALLOCATOR=y
+ CONFIG_HARDENED_USERCOPY=y
+ CONFIG_HARDENED_USERCOPY_FALLBACK=y
+ # CONFIG_HARDENED_USERCOPY_PAGESPAN is not set
+ CONFIG_FORTIFY_SOURCE=y
+ # CONFIG_STATIC_USERMODEHELPER is not set
+-CONFIG_SECURITY_SELINUX=y
+-CONFIG_SECURITY_SELINUX_BOOTPARAM=y
+-CONFIG_SECURITY_SELINUX_BOOTPARAM_VALUE=1
+-CONFIG_SECURITY_SELINUX_DISABLE=y
+-CONFIG_SECURITY_SELINUX_DEVELOP=y
+-CONFIG_SECURITY_SELINUX_AVC_STATS=y
+-CONFIG_SECURITY_SELINUX_CHECKREQPROT_VALUE=1
+ # CONFIG_SECURITY_SMACK is not set
+ # CONFIG_SECURITY_TOMOYO is not set
+ # CONFIG_SECURITY_APPARMOR is not set
+ # CONFIG_SECURITY_LOADPIN is not set
+ CONFIG_SECURITY_YAMA=y
+ # CONFIG_INTEGRITY is not set
+-CONFIG_DEFAULT_SECURITY_SELINUX=y
+-# CONFIG_DEFAULT_SECURITY_DAC is not set
+-CONFIG_DEFAULT_SECURITY="selinux"
++CONFIG_DEFAULT_SECURITY_DAC=y
++CONFIG_DEFAULT_SECURITY=""
+ CONFIG_XOR_BLOCKS=m
+ CONFIG_ASYNC_CORE=m
+ CONFIG_ASYNC_MEMCPY=m
+@@ -5505,7 +5558,6 @@ CONFIG_CRYPTO_NULL2=y
+ CONFIG_CRYPTO_PCRYPT=m
+ CONFIG_CRYPTO_WORKQUEUE=y
+ CONFIG_CRYPTO_CRYPTD=m
+-# CONFIG_CRYPTO_MCRYPTD is not set
+ CONFIG_CRYPTO_AUTHENC=m
+ CONFIG_CRYPTO_TEST=m
+ CONFIG_CRYPTO_SIMD=m
+@@ -5689,9 +5741,7 @@ CONFIG_CRC7=m
+ CONFIG_LIBCRC32C=m
+ CONFIG_CRC8=m
+ CONFIG_XXHASH=y
+-CONFIG_AUDIT_GENERIC=y
+ CONFIG_AUDIT_ARCH_COMPAT_GENERIC=y
+-CONFIG_AUDIT_COMPAT_GENERIC=y
+ # CONFIG_RANDOM32_SELFTEST is not set
+ CONFIG_ZLIB_INFLATE=y
+ CONFIG_ZLIB_DEFLATE=y
+@@ -5763,6 +5813,8 @@ CONFIG_ARCH_HAS_SG_CHAIN=y
+ CONFIG_ARCH_HAS_PMEM_API=y
+ CONFIG_ARCH_HAS_UACCESS_FLUSHCACHE=y
+ CONFIG_SBITMAP=y
++CONFIG_ETMEM_SCAN=m
++CONFIG_ETMEM_SWAP=m
+ # CONFIG_STRING_SELFTEST is not set
+ 
+ #
+@@ -5840,6 +5892,7 @@ CONFIG_SOFTLOCKUP_DETECTOR=y
+ CONFIG_BOOTPARAM_SOFTLOCKUP_PANIC_VALUE=0
+ CONFIG_SDEI_WATCHDOG=y
+ CONFIG_HARDLOCKUP_DETECTOR=y
++# CONFIG_CORELOCKUP_DETECTOR is not set
+ CONFIG_BOOTPARAM_HARDLOCKUP_PANIC=y
+ CONFIG_BOOTPARAM_HARDLOCKUP_PANIC_VALUE=1
+ CONFIG_DETECT_HUNG_TASK=y
+@@ -6000,9 +6053,3 @@ CONFIG_IO_STRICT_DEVMEM=y
+ # CONFIG_DEBUG_EFI is not set
+ # CONFIG_ARM64_RELOC_TEST is not set
+ # CONFIG_CORESIGHT is not set
+-CONFIG_SMMU_BYPASS_DEV=y
+-CONFIG_ETMEM_SCAN=m
+-CONFIG_ETMEM_SWAP=m
+-CONFIG_STAGING=y
+-CONFIG_GMJS_TCM_CORE=m
+-CONFIG_GMJS_TCM_SPI=m
+diff --git a/arch/x86/configs/openeuler_defconfig b/arch/x86/configs/openeuler_defconfig
+index 64f0805a5..10b413dc3 100644
+--- a/arch/x86/configs/openeuler_defconfig
++++ b/arch/x86/configs/openeuler_defconfig
+@@ -1,9 +1,17 @@
++#
++# Automatically generated file; DO NOT EDIT.
++# Linux/x86 4.19.90 Kernel Configuration
++#
++
++#
++# Compiler: gcc (GCC) 7.3.0
++#
+ CONFIG_CC_IS_GCC=y
+-CONFIG_GCC_VERSION=50400
++CONFIG_GCC_VERSION=70300
+ CONFIG_CLANG_VERSION=0
+ CONFIG_CC_HAS_ASM_GOTO=y
+ CONFIG_IRQ_WORK=y
+-CONFIG_BUILDTIME_EXTABLE_SORT=y
++CONFIG_BUILDTIME_TABLE_SORT=y
+ CONFIG_THREAD_INFO_IN_TASK=y
+ 
+ #
+@@ -34,11 +42,8 @@ CONFIG_POSIX_MQUEUE=y
+ CONFIG_POSIX_MQUEUE_SYSCTL=y
+ CONFIG_CROSS_MEMORY_ATTACH=y
+ # CONFIG_USELIB is not set
+-CONFIG_AUDIT=y
++# CONFIG_AUDIT is not set
+ CONFIG_HAVE_ARCH_AUDITSYSCALL=y
+-CONFIG_AUDITSYSCALL=y
+-CONFIG_AUDIT_WATCH=y
+-CONFIG_AUDIT_TREE=y
+ # CONFIG_KTASK is not set
+ 
+ #
+@@ -49,6 +54,8 @@ CONFIG_GENERIC_IRQ_SHOW=y
+ CONFIG_GENERIC_IRQ_EFFECTIVE_AFF_MASK=y
+ CONFIG_GENERIC_PENDING_IRQ=y
+ CONFIG_GENERIC_IRQ_MIGRATION=y
++CONFIG_GENERIC_IRQ_INJECTION=y
++CONFIG_HARDIRQS_SW_RESEND=y
+ CONFIG_IRQ_DOMAIN=y
+ CONFIG_IRQ_DOMAIN_HIERARCHY=y
+ CONFIG_GENERIC_MSI_IRQ=y
+@@ -129,8 +136,8 @@ CONFIG_BLK_CGROUP=y
+ # CONFIG_DEBUG_BLK_CGROUP is not set
+ CONFIG_CGROUP_WRITEBACK=y
+ CONFIG_CGROUP_SCHED=y
+-CONFIG_FAIR_GROUP_SCHED=y
+ CONFIG_QOS_SCHED=y
++CONFIG_FAIR_GROUP_SCHED=y
+ CONFIG_CFS_BANDWIDTH=y
+ CONFIG_RT_GROUP_SCHED=y
+ CONFIG_CGROUP_PIDS=y
+@@ -145,15 +152,15 @@ CONFIG_CGROUP_PERF=y
+ CONFIG_CGROUP_BPF=y
+ # CONFIG_CGROUP_DEBUG is not set
+ CONFIG_SOCK_CGROUP_DATA=y
+-CONFIG_CGROUP_FILES=y
++# CONFIG_CGROUP_FILES is not set
+ CONFIG_NAMESPACES=y
+ CONFIG_UTS_NS=y
+ CONFIG_IPC_NS=y
+ CONFIG_USER_NS=y
+ CONFIG_PID_NS=y
+ CONFIG_NET_NS=y
+-CONFIG_CHECKPOINT_RESTORE=y
+ CONFIG_SCHED_STEAL=y
++CONFIG_CHECKPOINT_RESTORE=y
+ CONFIG_SCHED_AUTOGROUP=y
+ # CONFIG_SYSFS_DEPRECATED is not set
+ CONFIG_RELAY=y
+@@ -194,6 +201,7 @@ CONFIG_TIMERFD=y
+ CONFIG_EVENTFD=y
+ CONFIG_SHMEM=y
+ CONFIG_AIO=y
++CONFIG_IO_URING=y
+ CONFIG_ADVISE_SYSCALLS=y
+ CONFIG_MEMBARRIER=y
+ CONFIG_KALLSYMS=y
+@@ -303,6 +311,7 @@ CONFIG_XEN_SAVE_RESTORE=y
+ # CONFIG_XEN_DEBUG_FS is not set
+ # CONFIG_XEN_PVH is not set
+ CONFIG_KVM_GUEST=y
++CONFIG_ARCH_CPUIDLE_HALTPOLL=y
+ # CONFIG_KVM_DEBUG_FS is not set
+ CONFIG_PARAVIRT_TIME_ACCOUNTING=y
+ CONFIG_PARAVIRT_CLOCK=y
+@@ -322,7 +331,9 @@ CONFIG_X86_MINIMUM_CPU_FAMILY=64
+ CONFIG_X86_DEBUGCTLMSR=y
+ CONFIG_CPU_SUP_INTEL=y
+ CONFIG_CPU_SUP_AMD=y
++CONFIG_CPU_SUP_HYGON=y
+ CONFIG_CPU_SUP_CENTAUR=y
++CONFIG_CPU_SUP_ZHAOXIN=y
+ CONFIG_HPET_TIMER=y
+ CONFIG_HPET_EMULATE_RTC=y
+ CONFIG_DMI=y
+@@ -395,7 +406,7 @@ CONFIG_X86_PAT=y
+ CONFIG_ARCH_USES_PG_UNCACHED=y
+ CONFIG_ARCH_RANDOM=y
+ CONFIG_X86_SMAP=y
+-CONFIG_X86_INTEL_UMIP=y
++CONFIG_X86_UMIP=y
+ # CONFIG_X86_INTEL_MPX is not set
+ CONFIG_X86_INTEL_MEMORY_PROTECTION_KEYS=y
+ CONFIG_X86_INTEL_TSX_MODE_OFF=y
+@@ -530,6 +541,7 @@ CONFIG_ACPI_APEI_EINJ=m
+ CONFIG_DPTF_POWER=m
+ CONFIG_ACPI_WATCHDOG=y
+ CONFIG_ACPI_EXTLOG=m
++CONFIG_ACPI_ADXL=y
+ CONFIG_PMIC_OPREGION=y
+ # CONFIG_ACPI_CONFIGFS is not set
+ CONFIG_X86_PM_TIMER=y
+@@ -700,12 +712,11 @@ CONFIG_FW_CFG_SYSFS=y
+ #
+ # EFI (Extensible Firmware Interface) Support
+ #
+-#CONFIG_EFI_VARS is not set
++# CONFIG_EFI_VARS is not set
+ CONFIG_EFI_ESRT=y
+ CONFIG_EFI_RUNTIME_MAP=y
+ # CONFIG_EFI_FAKE_MEMMAP is not set
+ CONFIG_EFI_RUNTIME_WRAPPERS=y
+-# CONFIG_EFI_BOOTLOADER_CONTROL is not set
+ # CONFIG_EFI_CAPSULE_LOADER is not set
+ # CONFIG_EFI_TEST is not set
+ CONFIG_APPLE_PROPERTIES=y
+@@ -730,6 +741,7 @@ CONFIG_KVM_VFIO=y
+ CONFIG_KVM_GENERIC_DIRTYLOG_READ_PROTECT=y
+ CONFIG_KVM_COMPAT=y
+ CONFIG_HAVE_KVM_IRQ_BYPASS=y
++CONFIG_HAVE_KVM_NO_POLL=y
+ CONFIG_VIRTUALIZATION=y
+ CONFIG_KVM=m
+ CONFIG_KVM_INTEL=m
+@@ -747,6 +759,7 @@ CONFIG_VHOST=m
+ #
+ CONFIG_CRASH_CORE=y
+ CONFIG_KEXEC_CORE=y
++# CONFIG_QUICK_KEXEC is not set
+ CONFIG_HOTPLUG_SMT=y
+ CONFIG_OPROFILE=m
+ CONFIG_OPROFILE_EVENT_MULTIPLEX=y
+@@ -841,9 +854,8 @@ CONFIG_ARCH_USE_MEMREMAP_PROT=y
+ #
+ # CONFIG_GCOV_KERNEL is not set
+ CONFIG_ARCH_HAS_GCOV_PROFILE_ALL=y
+-CONFIG_PLUGIN_HOSTCC="g++"
++CONFIG_PLUGIN_HOSTCC=""
+ CONFIG_HAVE_GCC_PLUGINS=y
+-# CONFIG_GCC_PLUGINS is not set
+ CONFIG_RT_MUTEXES=y
+ CONFIG_BASE_SMALL=0
+ CONFIG_MODULES=y
+@@ -982,6 +994,7 @@ CONFIG_MIGRATION=y
+ CONFIG_PHYS_ADDR_T_64BIT=y
+ CONFIG_BOUNCE=y
+ CONFIG_VIRT_TO_BUS=y
++CONFIG_MM_OWNER=y
+ CONFIG_MMU_NOTIFIER=y
+ CONFIG_KSM=y
+ CONFIG_DEFAULT_MMAP_MIN_ADDR=4096
+@@ -998,6 +1011,7 @@ CONFIG_CLEANCACHE=y
+ CONFIG_FRONTSWAP=y
+ CONFIG_SHRINK_PAGECACHE=y
+ CONFIG_USERSWAP=y
++CONFIG_MEMCG_QOS=y
+ # CONFIG_CMA is not set
+ CONFIG_MEM_SOFT_DIRTY=y
+ CONFIG_ZSWAP=y
+@@ -1035,6 +1049,7 @@ CONFIG_NET_EGRESS=y
+ CONFIG_PACKET=y
+ CONFIG_PACKET_DIAG=m
+ CONFIG_UNIX=y
++CONFIG_UNIX_SCM=y
+ CONFIG_UNIX_DIAG=m
+ CONFIG_TLS=m
+ CONFIG_TLS_DEVICE=y
+@@ -1245,7 +1260,6 @@ CONFIG_NETFILTER_XT_SET=m
+ #
+ # Xtables targets
+ #
+-CONFIG_NETFILTER_XT_TARGET_AUDIT=m
+ CONFIG_NETFILTER_XT_TARGET_CHECKSUM=m
+ CONFIG_NETFILTER_XT_TARGET_CLASSIFY=m
+ CONFIG_NETFILTER_XT_TARGET_CONNMARK=m
+@@ -1854,6 +1868,7 @@ CONFIG_DEV_COREDUMP=y
+ # CONFIG_DEBUG_DRIVER is not set
+ # CONFIG_DEBUG_DEVRES is not set
+ # CONFIG_DEBUG_TEST_DRIVER_REMOVE is not set
++CONFIG_HMEM_REPORTING=y
+ # CONFIG_TEST_ASYNC_DRIVER_PROBE is not set
+ CONFIG_SYS_HYPERVISOR=y
+ CONFIG_GENERIC_CPU_AUTOPROBE=y
+@@ -2111,6 +2126,7 @@ CONFIG_VMWARE_VMCI=m
+ # CONFIG_ECHO is not set
+ CONFIG_MISC_RTSX_PCI=m
+ CONFIG_MISC_RTSX_USB=m
++# CONFIG_UACCE is not set
+ CONFIG_HAVE_IDE=y
+ # CONFIG_IDE is not set
+ 
+@@ -2211,10 +2227,10 @@ CONFIG_SCSI_QLA_FC=m
+ CONFIG_SCSI_QLA_ISCSI=m
+ CONFIG_QEDI=m
+ CONFIG_QEDF=m
+-CONFIG_SCSI_LPFC=m
+-# CONFIG_SCSI_LPFC_DEBUG_FS is not set
+ CONFIG_SCSI_HUAWEI_FC=m
+ CONFIG_SCSI_FC_HIFC=m
++CONFIG_SCSI_LPFC=m
++# CONFIG_SCSI_LPFC_DEBUG_FS is not set
+ # CONFIG_SCSI_DC395x is not set
+ # CONFIG_SCSI_AM53C974 is not set
+ # CONFIG_SCSI_WD719X is not set
+@@ -2269,6 +2285,7 @@ CONFIG_ATA_PIIX=m
+ # CONFIG_SATA_ULI is not set
+ # CONFIG_SATA_VIA is not set
+ # CONFIG_SATA_VITESSE is not set
++# CONFIG_SATA_ZHAOXIN is not set
+ 
+ #
+ # PATA SFF controllers with BMDMA
+@@ -2516,17 +2533,15 @@ CONFIG_BE2NET_LANCER=y
+ CONFIG_BE2NET_SKYHAWK=y
+ # CONFIG_NET_VENDOR_EZCHIP is not set
+ # CONFIG_NET_VENDOR_HP is not set
++CONFIG_NET_VENDOR_HUAWEI=y
++CONFIG_HINIC=m
+ CONFIG_BMA=m
+ # CONFIG_NET_VENDOR_I825XX is not set
+-CONFIG_NET_VENDOR_NETSWIFT=y
+-CONFIG_TXGBE=m
+-CONFIG_NGBE=m
+ CONFIG_NET_VENDOR_INTEL=y
+ # CONFIG_E100 is not set
+ CONFIG_E1000=m
+ CONFIG_E1000E=m
+ CONFIG_E1000E_HWTS=y
+-CONFIG_HINIC=m
+ CONFIG_IGB=m
+ CONFIG_IGB_HWMON=y
+ CONFIG_IGB_DCA=y
+@@ -2542,6 +2557,15 @@ CONFIG_I40E_DCB=y
+ CONFIG_I40EVF=m
+ CONFIG_ICE=m
+ CONFIG_FM10K=m
++CONFIG_NET_VENDOR_NETSWIFT=y
++CONFIG_TXGBE=m
++CONFIG_NGBE=m
++# CONFIG_NGBE_HWMON is not set
++# CONFIG_NGBE_PROCFS is not set
++# CONFIG_NGBE_NO_LLI is not set
++# CONFIG_NGBE_DEBUG_FS is not set
++# CONFIG_NGBE_POLL_LINK_STATUS is not set
++# CONFIG_NGBE_SYSFS is not set
+ # CONFIG_JME is not set
+ # CONFIG_NET_VENDOR_MARVELL is not set
+ CONFIG_NET_VENDOR_MELLANOX=y
+@@ -3529,6 +3553,7 @@ CONFIG_SPI_MASTER=y
+ # CONFIG_SPI_LOOPBACK_TEST is not set
+ # CONFIG_SPI_TLE62X0 is not set
+ # CONFIG_SPI_SLAVE is not set
++CONFIG_SPI_DYNAMIC=y
+ # CONFIG_SPMI is not set
+ # CONFIG_HSI is not set
+ CONFIG_PPS=y
+@@ -3620,6 +3645,7 @@ CONFIG_GPIO_ICH=m
+ # PCI GPIO expanders
+ #
+ # CONFIG_GPIO_AMD8111 is not set
++# CONFIG_GPIO_BT8XX is not set
+ # CONFIG_GPIO_ML_IOH is not set
+ # CONFIG_GPIO_PCI_IDIO_16 is not set
+ # CONFIG_GPIO_PCIE_IDIO_24 is not set
+@@ -4096,9 +4122,6 @@ CONFIG_VIDEO_V4L2=m
+ # CONFIG_VIDEO_ADV_DEBUG is not set
+ # CONFIG_VIDEO_FIXED_MINOR_RANGES is not set
+ CONFIG_VIDEO_TUNER=m
+-CONFIG_VIDEOBUF_GEN=m
+-CONFIG_VIDEOBUF_DMA_SG=m
+-CONFIG_VIDEOBUF_VMALLOC=m
+ CONFIG_DVB_CORE=m
+ # CONFIG_DVB_MMAP is not set
+ CONFIG_DVB_NET=y
+@@ -4172,7 +4195,6 @@ CONFIG_USB_PWC=m
+ # CONFIG_USB_PWC_DEBUG is not set
+ CONFIG_USB_PWC_INPUT_EVDEV=y
+ # CONFIG_VIDEO_CPIA2 is not set
+-CONFIG_USB_ZR364XX=m
+ CONFIG_USB_STKWEBCAM=m
+ CONFIG_USB_S2255=m
+ # CONFIG_VIDEO_USBTV is not set
+@@ -4195,13 +4217,6 @@ CONFIG_VIDEO_USBVISION=m
+ CONFIG_VIDEO_AU0828=m
+ CONFIG_VIDEO_AU0828_V4L2=y
+ # CONFIG_VIDEO_AU0828_RC is not set
+-CONFIG_VIDEO_CX231XX=m
+-CONFIG_VIDEO_CX231XX_RC=y
+-CONFIG_VIDEO_CX231XX_ALSA=m
+-CONFIG_VIDEO_CX231XX_DVB=m
+-CONFIG_VIDEO_TM6000=m
+-CONFIG_VIDEO_TM6000_ALSA=m
+-CONFIG_VIDEO_TM6000_DVB=m
+ 
+ #
+ # Digital TV USB devices
+@@ -4286,16 +4301,11 @@ CONFIG_VIDEO_IVTV=m
+ # CONFIG_VIDEO_IVTV_DEPRECATED_IOCTLS is not set
+ # CONFIG_VIDEO_IVTV_ALSA is not set
+ CONFIG_VIDEO_FB_IVTV=m
+-# CONFIG_VIDEO_HEXIUM_GEMINI is not set
+-# CONFIG_VIDEO_HEXIUM_ORION is not set
+-# CONFIG_VIDEO_MXB is not set
+ # CONFIG_VIDEO_DT3155 is not set
+ 
+ #
+ # Media capture/analog/hybrid TV support
+ #
+-CONFIG_VIDEO_CX18=m
+-CONFIG_VIDEO_CX18_ALSA=m
+ CONFIG_VIDEO_CX23885=m
+ CONFIG_MEDIA_ALTERA_CI=m
+ # CONFIG_VIDEO_CX25821 is not set
+@@ -4305,8 +4315,6 @@ CONFIG_VIDEO_CX88_BLACKBIRD=m
+ CONFIG_VIDEO_CX88_DVB=m
+ # CONFIG_VIDEO_CX88_ENABLE_VP3054 is not set
+ CONFIG_VIDEO_CX88_MPEG=m
+-CONFIG_VIDEO_BT848=m
+-CONFIG_DVB_BT8XX=m
+ CONFIG_VIDEO_SAA7134=m
+ CONFIG_VIDEO_SAA7134_ALSA=m
+ CONFIG_VIDEO_SAA7134_RC=y
+@@ -4316,14 +4324,9 @@ CONFIG_VIDEO_SAA7164=m
+ #
+ # Media digital TV PCI Adapters
+ #
+-CONFIG_DVB_AV7110_IR=y
+-CONFIG_DVB_AV7110=m
+-CONFIG_DVB_AV7110_OSD=y
+ CONFIG_DVB_BUDGET_CORE=m
+ CONFIG_DVB_BUDGET=m
+ CONFIG_DVB_BUDGET_CI=m
+-CONFIG_DVB_BUDGET_AV=m
+-CONFIG_DVB_BUDGET_PATCH=m
+ CONFIG_DVB_B2C2_FLEXCOP_PCI=m
+ # CONFIG_DVB_B2C2_FLEXCOP_PCI_DEBUG is not set
+ CONFIG_DVB_PLUTO2=m
+@@ -4390,7 +4393,6 @@ CONFIG_VIDEOBUF2_DMA_SG=m
+ CONFIG_VIDEOBUF2_DVB=m
+ CONFIG_DVB_B2C2_FLEXCOP=m
+ CONFIG_VIDEO_SAA7146=m
+-CONFIG_VIDEO_SAA7146_VV=m
+ CONFIG_SMS_SIANO_MDTV=m
+ CONFIG_SMS_SIANO_RC=y
+ # CONFIG_SMS_SIANO_DEBUGFS is not set
+@@ -4405,11 +4407,8 @@ CONFIG_VIDEO_IR_I2C=m
+ #
+ # Audio decoders, processors and mixers
+ #
+-CONFIG_VIDEO_TVAUDIO=m
+-CONFIG_VIDEO_TDA7432=m
+ CONFIG_VIDEO_MSP3400=m
+ CONFIG_VIDEO_CS3308=m
+-CONFIG_VIDEO_CS5345=m
+ CONFIG_VIDEO_CS53L32A=m
+ CONFIG_VIDEO_WM8775=m
+ CONFIG_VIDEO_WM8739=m
+@@ -4533,7 +4532,6 @@ CONFIG_DVB_MN88473=m
+ #
+ # DVB-S (satellite) frontends
+ #
+-CONFIG_DVB_CX24110=m
+ CONFIG_DVB_CX24123=m
+ CONFIG_DVB_MT312=m
+ CONFIG_DVB_ZL10036=m
+@@ -4546,12 +4544,10 @@ CONFIG_DVB_STV6110=m
+ CONFIG_DVB_STV0900=m
+ CONFIG_DVB_TDA8083=m
+ CONFIG_DVB_TDA10086=m
+-CONFIG_DVB_TDA8261=m
+ CONFIG_DVB_VES1X93=m
+ CONFIG_DVB_TUNER_ITD1000=m
+ CONFIG_DVB_TUNER_CX24113=m
+ CONFIG_DVB_TDA826X=m
+-CONFIG_DVB_TUA6100=m
+ CONFIG_DVB_CX24116=m
+ CONFIG_DVB_CX24117=m
+ CONFIG_DVB_CX24120=m
+@@ -4564,8 +4560,6 @@ CONFIG_DVB_TDA10071=m
+ #
+ # DVB-T (terrestrial) frontends
+ #
+-CONFIG_DVB_SP8870=m
+-CONFIG_DVB_SP887X=m
+ CONFIG_DVB_CX22700=m
+ CONFIG_DVB_CX22702=m
+ CONFIG_DVB_DRXD=m
+@@ -4601,7 +4595,6 @@ CONFIG_DVB_STV0297=m
+ # ATSC (North American/Korean Terrestrial/Cable DTV) frontends
+ #
+ CONFIG_DVB_NXT200X=m
+-CONFIG_DVB_OR51211=m
+ CONFIG_DVB_OR51132=m
+ CONFIG_DVB_BCM3510=m
+ CONFIG_DVB_LGDT330X=m
+@@ -4871,9 +4864,6 @@ CONFIG_HDMI=y
+ # Console display driver support
+ #
+ CONFIG_VGA_CONSOLE=y
+-CONFIG_VGACON_SOFT_SCROLLBACK=y
+-CONFIG_VGACON_SOFT_SCROLLBACK_SIZE=64
+-# CONFIG_VGACON_SOFT_SCROLLBACK_PERSISTENT_ENABLE_BY_DEFAULT is not set
+ CONFIG_DUMMY_CONSOLE=y
+ CONFIG_DUMMY_CONSOLE_COLUMNS=80
+ CONFIG_DUMMY_CONSOLE_ROWS=25
+@@ -6080,6 +6070,10 @@ CONFIG_MLX_PLATFORM=m
+ CONFIG_INTEL_TURBO_MAX_3=y
+ # CONFIG_I2C_MULTI_INSTANTIATE is not set
+ # CONFIG_INTEL_ATOMISP2_PM is not set
++
++#
++# Intel Speed Select Technology interface support
++#
+ CONFIG_INTEL_SPEED_SELECT_INTERFACE=m
+ CONFIG_PMC_ATOM=y
+ # CONFIG_CHROME_PLATFORMS is not set
+@@ -6564,6 +6558,7 @@ CONFIG_ARM_GIC_MAX_NR=1
+ # CONFIG_PHY_PXA_28NM_USB2 is not set
+ # CONFIG_PHY_CPCAP_USB is not set
+ CONFIG_POWERCAP=y
++CONFIG_INTEL_RAPL_CORE=m
+ CONFIG_INTEL_RAPL=m
+ # CONFIG_IDLE_INJECT is not set
+ # CONFIG_MCB is not set
+@@ -6593,6 +6588,7 @@ CONFIG_DAX=y
+ CONFIG_DEV_DAX=m
+ CONFIG_DEV_DAX_PMEM=m
+ CONFIG_DEV_DAX_KMEM=m
++CONFIG_DEV_DAX_PMEM_COMPAT=m
+ CONFIG_NVMEM=y
+ 
+ #
+@@ -6610,10 +6606,10 @@ CONFIG_INTEL_TH_GTH=m
+ CONFIG_INTEL_TH_STH=m
+ CONFIG_INTEL_TH_MSU=m
+ CONFIG_INTEL_TH_PTI=m
++# CONFIG_INTEL_TH_DEBUG is not set
+ # CONFIG_FPGA is not set
+ # CONFIG_UNISYS_VISORBUS is not set
+ # CONFIG_SIOX is not set
+-# CONFIG_UACCE is not set
+ # CONFIG_SLIMBUS is not set
+ 
+ #
+@@ -6629,6 +6625,7 @@ CONFIG_EXT4_FS_POSIX_ACL=y
+ CONFIG_EXT4_FS_SECURITY=y
+ # CONFIG_EXT4_ENCRYPTION is not set
+ # CONFIG_EXT4_DEBUG is not set
++# CONFIG_EXT4_PARALLEL_DIO_READ is not set
+ CONFIG_JBD2=m
+ # CONFIG_JBD2_DEBUG is not set
+ CONFIG_FS_MBCACHE=m
+@@ -6725,6 +6722,7 @@ CONFIG_SYSFS=y
+ CONFIG_TMPFS=y
+ CONFIG_TMPFS_POSIX_ACL=y
+ CONFIG_TMPFS_XATTR=y
++# CONFIG_TMPFS_INODE64 is not set
+ CONFIG_HUGETLBFS=y
+ CONFIG_HUGETLB_PAGE=y
+ CONFIG_MEMFD_CREATE=y
+@@ -6901,6 +6899,7 @@ CONFIG_NLS_MAC_TURKISH=m
+ CONFIG_NLS_UTF8=m
+ CONFIG_DLM=m
+ CONFIG_DLM_DEBUG=y
++CONFIG_IO_WQ=y
+ 
+ #
+ # Security options
+@@ -6914,7 +6913,6 @@ CONFIG_ENCRYPTED_KEYS=y
+ # CONFIG_KEY_DH_OPERATIONS is not set
+ # CONFIG_SECURITY_DMESG_RESTRICT is not set
+ CONFIG_SECURITY=y
+-CONFIG_SECURITY_WRITABLE_HOOKS=y
+ CONFIG_SECURITYFS=y
+ CONFIG_SECURITY_NETWORK=y
+ CONFIG_PAGE_TABLE_ISOLATION=y
+@@ -6922,19 +6920,11 @@ CONFIG_SECURITY_INFINIBAND=y
+ CONFIG_SECURITY_NETWORK_XFRM=y
+ # CONFIG_SECURITY_PATH is not set
+ CONFIG_INTEL_TXT=y
+-CONFIG_LSM_MMAP_MIN_ADDR=65535
+ CONFIG_HAVE_HARDENED_USERCOPY_ALLOCATOR=y
+ CONFIG_HARDENED_USERCOPY=y
+ CONFIG_HARDENED_USERCOPY_FALLBACK=y
+ CONFIG_FORTIFY_SOURCE=y
+ # CONFIG_STATIC_USERMODEHELPER is not set
+-CONFIG_SECURITY_SELINUX=y
+-CONFIG_SECURITY_SELINUX_BOOTPARAM=y
+-CONFIG_SECURITY_SELINUX_BOOTPARAM_VALUE=1
+-CONFIG_SECURITY_SELINUX_DISABLE=y
+-CONFIG_SECURITY_SELINUX_DEVELOP=y
+-CONFIG_SECURITY_SELINUX_AVC_STATS=y
+-CONFIG_SECURITY_SELINUX_CHECKREQPROT_VALUE=1
+ # CONFIG_SECURITY_SMACK is not set
+ # CONFIG_SECURITY_TOMOYO is not set
+ # CONFIG_SECURITY_APPARMOR is not set
+@@ -6944,10 +6934,8 @@ CONFIG_INTEGRITY=y
+ CONFIG_INTEGRITY_SIGNATURE=y
+ CONFIG_INTEGRITY_ASYMMETRIC_KEYS=y
+ CONFIG_INTEGRITY_TRUSTED_KEYRING=y
+-CONFIG_INTEGRITY_AUDIT=y
+ CONFIG_IMA=y
+ CONFIG_IMA_MEASURE_PCR_IDX=10
+-CONFIG_IMA_LSM_RULES=y
+ # CONFIG_IMA_TEMPLATE is not set
+ CONFIG_IMA_NG_TEMPLATE=y
+ # CONFIG_IMA_SIG_TEMPLATE is not set
+@@ -6967,9 +6955,8 @@ CONFIG_EVM=y
+ CONFIG_EVM_ATTR_FSUUID=y
+ # CONFIG_EVM_ADD_XATTRS is not set
+ # CONFIG_EVM_LOAD_X509 is not set
+-CONFIG_DEFAULT_SECURITY_SELINUX=y
+-# CONFIG_DEFAULT_SECURITY_DAC is not set
+-CONFIG_DEFAULT_SECURITY="selinux"
++CONFIG_DEFAULT_SECURITY_DAC=y
++CONFIG_DEFAULT_SECURITY=""
+ CONFIG_XOR_BLOCKS=m
+ CONFIG_ASYNC_CORE=m
+ CONFIG_ASYNC_MEMCPY=m
+@@ -7297,6 +7284,8 @@ CONFIG_ARCH_HAS_UACCESS_FLUSHCACHE=y
+ CONFIG_ARCH_HAS_UACCESS_MCSAFE=y
+ CONFIG_SBITMAP=y
+ CONFIG_PARMAN=m
++CONFIG_ETMEM_SCAN=m
++CONFIG_ETMEM_SWAP=m
+ # CONFIG_STRING_SELFTEST is not set
+ 
+ #
+@@ -7362,6 +7351,8 @@ CONFIG_DEBUG_STACKOVERFLOW=y
+ CONFIG_HAVE_ARCH_KASAN=y
+ # CONFIG_KASAN is not set
+ CONFIG_ARCH_HAS_KCOV=y
++CONFIG_CC_HAS_SANCOV_TRACE_PC=y
++# CONFIG_KCOV is not set
+ CONFIG_DEBUG_SHIRQ=y
+ 
+ #
+@@ -7569,5 +7560,3 @@ CONFIG_OPTIMIZE_INLINING=y
+ # CONFIG_PUNIT_ATOM_DEBUG is not set
+ CONFIG_UNWINDER_ORC=y
+ # CONFIG_UNWINDER_FRAME_POINTER is not set
+-CONFIG_ETMEM_SCAN=m
+-CONFIG_ETMEM_SWAP=m
+-- 
+2.27.0
+
diff -Nur kernel/0001-kconfig-enable-pin-memory-and-quick-kexec-for-x86.patch obs_kernel/0001-kconfig-enable-pin-memory-and-quick-kexec-for-x86.patch
--- kernel/0001-kconfig-enable-pin-memory-and-quick-kexec-for-x86.patch	1970-01-01 08:00:00.000000000 +0800
+++ obs_kernel/0001-kconfig-enable-pin-memory-and-quick-kexec-for-x86.patch	2022-10-26 15:28:30.000000000 +0800
@@ -0,0 +1,41 @@
+From bb87e8b9c3a773aecfbb2b12879b384746b3101e Mon Sep 17 00:00:00 2001
+From: hongrongxuan <hongrongxuan@huawei.com>
+Date: Tue, 25 Oct 2022 01:15:53 +0800
+Subject: [PATCH] kexec for patch
+
+---
+ arch/x86/configs/openeuler_defconfig | 4 ++++
+ mm/Kconfig                           | 2 +-
+ 2 files changed, 5 insertions(+), 1 deletion(-)
+
+diff --git a/arch/x86/configs/openeuler_defconfig b/arch/x86/configs/openeuler_defconfig
+index 10b413dc3..60d58909b 100644
+--- a/arch/x86/configs/openeuler_defconfig
++++ b/arch/x86/configs/openeuler_defconfig
+@@ -7286,6 +7286,10 @@ CONFIG_SBITMAP=y
+ CONFIG_PARMAN=m
+ CONFIG_ETMEM_SCAN=m
+ CONFIG_ETMEM_SWAP=m
++CONFIG_PIN_MEMORY=y
++CONFIG_PID_RESERVE=y
++CONFIG_PIN_MEMORY_DEV=m
++CONFIG_QUICK_KEXEC=y
+ # CONFIG_STRING_SELFTEST is not set
+ 
+ #
+diff --git a/mm/Kconfig b/mm/Kconfig
+index 12601505c..b7b6650ba 100644
+--- a/mm/Kconfig
++++ b/mm/Kconfig
+@@ -815,7 +815,7 @@ config ARCH_HAS_PTE_SPECIAL
+ 
+ config PIN_MEMORY
+ 	bool "Support for pin memory"
+-	depends on MMU && ARM64
++	depends on MMU
+ 	help
+ 	  Say y here to enable the pin memory feature for checkpoint
+ 	  and restore. We can pin the memory data of tasks and collect
+-- 
+2.27.0
+
diff -Nur kernel/0001-kconfig-enable-pin-memory-default.patch obs_kernel/0001-kconfig-enable-pin-memory-default.patch
--- kernel/0001-kconfig-enable-pin-memory-default.patch	1970-01-01 08:00:00.000000000 +0800
+++ obs_kernel/0001-kconfig-enable-pin-memory-default.patch	2022-10-18 12:31:10.000000000 +0800
@@ -0,0 +1,34 @@
+From 95008648b93c4dad92dfc93dd460a21908572576 Mon Sep 17 00:00:00 2001
+From: "he@he.net" <he@he.net>
+Date: Tue, 18 Oct 2022 12:15:38 +0800
+Subject: [PATCH 1/1] kconfig: enable pin memory default
+
+---
+ mm/Kconfig | 4 +++-
+ 1 file changed, 3 insertions(+), 1 deletion(-)
+
+diff --git a/mm/Kconfig b/mm/Kconfig
+index e607d1576..bb16ad50a 100644
+--- a/mm/Kconfig
++++ b/mm/Kconfig
+@@ -815,7 +815,8 @@ config ARCH_HAS_PTE_SPECIAL
+ 
+ config PIN_MEMORY
+ 	bool "Support for pin memory"
+-	depends on MMU && ARM64
++	depends on MMU
++	default y
+ 	help
+ 	  Say y here to enable the pin memory feature for checkpoint
+ 	  and restore. We can pin the memory data of tasks and collect
+@@ -825,6 +826,7 @@ config PIN_MEMORY
+ config PID_RESERVE
+ 	bool "Support for reserve and recover pid"
+ 	depends on PIN_MEMORY
++	default y
+ 	help
+ 	  Say y here to enable the pid reserved feature for checkpoint.
+ 	  and restore.
+-- 
+2.20.1
+
diff -Nur kernel/0001-kexec-provide-generic-quick-kexec-cmdline-parsing-AP.patch obs_kernel/0001-kexec-provide-generic-quick-kexec-cmdline-parsing-AP.patch
--- kernel/0001-kexec-provide-generic-quick-kexec-cmdline-parsing-AP.patch	1970-01-01 08:00:00.000000000 +0800
+++ obs_kernel/0001-kexec-provide-generic-quick-kexec-cmdline-parsing-AP.patch	2022-10-14 15:29:25.000000000 +0800
@@ -0,0 +1,70 @@
+From faae61f5993c00335e00d0aa1d35b09c255ae082 Mon Sep 17 00:00:00 2001
+From: "fu.lin" <fulin10@huawei.com>
+Date: Fri, 14 Oct 2022 11:36:28 +0800
+Subject: [PATCH 1/4] kexec: provide generic quick kexec cmdline parsing API
+
+---
+ include/linux/crash_core.h |  5 +++++
+ include/linux/kexec.h      |  5 +++++
+ kernel/crash_core.c        | 11 +++++++++++
+ 3 files changed, 21 insertions(+)
+
+diff --git a/include/linux/crash_core.h b/include/linux/crash_core.h
+index a74a87857..a34833177 100644
+--- a/include/linux/crash_core.h
++++ b/include/linux/crash_core.h
+@@ -36,6 +36,11 @@ __printf(1, 2)
+ void vmcoreinfo_append_str(const char *fmt, ...);
+ phys_addr_t paddr_vmcoreinfo_note(void);
+ 
++#ifdef CONFIG_QUICK_KEXEC
++int __init parse_quick_kexec(char *cmdline, unsigned long long system_ram,
++			  unsigned long long *crash_size, unsigned long long *crash_base);
++#endif /* CONFIG_QUICK_KEXEC */
++
+ #define VMCOREINFO_OSRELEASE(value) \
+ 	vmcoreinfo_append_str("OSRELEASE=%s\n", value)
+ #define VMCOREINFO_PAGESIZE(value) \
+diff --git a/include/linux/kexec.h b/include/linux/kexec.h
+index 98cf0fb09..fe6c8e9c3 100644
+--- a/include/linux/kexec.h
++++ b/include/linux/kexec.h
+@@ -303,8 +303,13 @@ extern int kexec_load_disabled;
+ #endif
+ 
+ /* List of defined/legal kexec file flags */
++#ifndef CONFIG_QUICK_KEXEC
+ #define KEXEC_FILE_FLAGS	(KEXEC_FILE_UNLOAD | KEXEC_FILE_ON_CRASH | \
+ 				 KEXEC_FILE_NO_INITRAMFS)
++#else
++#define KEXEC_FILE_FLAGS	(KEXEC_FILE_UNLOAD | KEXEC_FILE_ON_CRASH | \
++				 KEXEC_FILE_NO_INITRAMFS | KEXEC_QUICK)
++#endif
+ 
+ /* Location of a reserved region to hold the crash kernel.
+  */
+diff --git a/kernel/crash_core.c b/kernel/crash_core.c
+index 7e65e1008..54f1a4ccf 100644
+--- a/kernel/crash_core.c
++++ b/kernel/crash_core.c
+@@ -276,6 +276,17 @@ int __init parse_crashkernel(char *cmdline,
+ 					"crashkernel=", NULL);
+ }
+ 
++#ifdef CONFIG_QUICK_KEXEC
++int __init parse_quick_kexec(char *cmdline,
++			  unsigned long long system_ram,
++			  unsigned long long *mem_size,
++			  unsigned long long *mem_base)
++{
++	return __parse_crashkernel(cmdline, system_ram, mem_size, mem_base,
++			"quickkexec=", NULL);
++}
++#endif
++
+ int __init parse_crashkernel_high(char *cmdline,
+ 			     unsigned long long system_ram,
+ 			     unsigned long long *crash_size,
+-- 
+2.27.0
+
diff -Nur kernel/0001-pinmem-fix-build.patch obs_kernel/0001-pinmem-fix-build.patch
--- kernel/0001-pinmem-fix-build.patch	1970-01-01 08:00:00.000000000 +0800
+++ obs_kernel/0001-pinmem-fix-build.patch	2022-10-18 14:04:29.000000000 +0800
@@ -0,0 +1,27 @@
+From 5624d06094bec6432219c5e4f4c59ca2b6d67af1 Mon Sep 17 00:00:00 2001
+From: "he@he.net" <he@he.net>
+Date: Tue, 18 Oct 2022 14:03:38 +0800
+Subject: [PATCH 1/1] pinmem: fix build
+
+---
+ mm/pin_mem.c | 4 ++++
+ 1 file changed, 4 insertions(+)
+
+diff --git a/mm/pin_mem.c b/mm/pin_mem.c
+index d03593472..7c775eceb 100644
+--- a/mm/pin_mem.c
++++ b/mm/pin_mem.c
+@@ -21,6 +21,10 @@
+ #define MAX_PIN_PID_NUM  128
+ #define DEFAULT_REDIRECT_SPACE_SIZE  0x100000
+ 
++#ifndef phys_to_page
++# define phys_to_page(phys)	(pfn_to_page(__phys_to_pfn(phys)))
++#endif
++
+ static DEFINE_SPINLOCK(page_map_entry_lock);
+ static DEFINE_MUTEX(pin_mem_mutex);
+ static struct pin_mem_dump_info *pin_mem_dump_start;
+-- 
+2.20.1
+
diff -Nur kernel/0002-arm64-change-quick-memory-parsing-API.patch obs_kernel/0002-arm64-change-quick-memory-parsing-API.patch
--- kernel/0002-arm64-change-quick-memory-parsing-API.patch	1970-01-01 08:00:00.000000000 +0800
+++ obs_kernel/0002-arm64-change-quick-memory-parsing-API.patch	2022-10-14 15:29:25.000000000 +0800
@@ -0,0 +1,65 @@
+From ed6f44cae21809c358aefa3117d66b9ebeae0b65 Mon Sep 17 00:00:00 2001
+From: "fu.lin" <fulin10@huawei.com>
+Date: Fri, 14 Oct 2022 11:36:48 +0800
+Subject: [PATCH 2/4] arm64: change quick memory parsing API
+
+---
+ arch/arm64/mm/init.c | 27 +++++++++------------------
+ 1 file changed, 9 insertions(+), 18 deletions(-)
+
+diff --git a/arch/arm64/mm/init.c b/arch/arm64/mm/init.c
+index 8cdf92626..1b4db28e2 100644
+--- a/arch/arm64/mm/init.c
++++ b/arch/arm64/mm/init.c
+@@ -244,22 +244,15 @@ static void __init kexec_reserve_crashkres_pages(void)
+ #endif /* CONFIG_KEXEC_CORE */
+ 
+ #ifdef CONFIG_QUICK_KEXEC
+-static int __init parse_quick_kexec(char *p)
+-{
+-	if (!p)
+-		return 0;
+-
+-	quick_kexec_res.end = PAGE_ALIGN(memparse(p, NULL));
+-
+-	return 0;
+-}
+-early_param("quickkexec", parse_quick_kexec);
+-
+ static void __init reserve_quick_kexec(void)
+ {
+-	unsigned long long mem_start, mem_len;
++	int ret;
++	struct resource *res;
++	unsigned long long mem_len = 0;
++	unsigned long long mem_start = 0;
+ 
+-	mem_len = quick_kexec_res.end;
++	ret = parse_quick_kexec(boot_command_line, memblock_phys_mem_size(),
++			&mem_len, &mem_start);
+ 	if (mem_len == 0)
+ 		return;
+ 
+@@ -269,16 +262,14 @@ static void __init reserve_quick_kexec(void)
+ 	if (mem_start == 0) {
+ 		pr_warn("cannot allocate quick kexec mem (size:0x%llx)\n",
+ 			mem_len);
+-		quick_kexec_res.end = 0;
+ 		return;
+ 	}
+ 
+ 	memblock_reserve(mem_start, mem_len);
+-	pr_info("quick kexec mem reserved: 0x%016llx - 0x%016llx (%lld MB)\n",
+-		mem_start, mem_start + mem_len,	mem_len >> 20);
+ 
+-	quick_kexec_res.start = mem_start;
+-	quick_kexec_res.end = mem_start + mem_len - 1;
++	res = &quick_kexec_res;
++	res->start = mem_start;
++	res->end = mem_start + mem_len - 1;
+ }
+ #endif
+ 
+-- 
+2.27.0
+
diff -Nur kernel/0003-x86-add-support-for-quick-kexec.patch obs_kernel/0003-x86-add-support-for-quick-kexec.patch
--- kernel/0003-x86-add-support-for-quick-kexec.patch	1970-01-01 08:00:00.000000000 +0800
+++ obs_kernel/0003-x86-add-support-for-quick-kexec.patch	2022-10-18 19:36:19.000000000 +0800
@@ -0,0 +1,83 @@
+From ceba2e8a37f6e2bac895be0a6f5051cd85877107 Mon Sep 17 00:00:00 2001
+From: hewenliang <hewenliang4@huawei.com>
+Date: Sat, 13 Nov 2021 11:25:53 +0800
+Subject: [PATCH 3/4] x86: add support for quick kexec
+
+Signed-off-by: Tie Liu <liutie4@huawei.com>
+Signed-off-by: Jingxian He <hejingxian@huawei.com>
+Signed-off-by: Wenliang He <hewenliang4@huawei.com>
+Signed-off-by: fu.lin <fulin10@huawei.com>
+---
+ arch/x86/kernel/setup.c | 42 ++++++++++++++++++++++++++++++++++++++++-
+ 1 file changed, 41 insertions(+), 1 deletion(-)
+
+diff --git a/arch/x86/kernel/setup.c b/arch/x86/kernel/setup.c
+index c63f2e41e..0d265961c 100644
+--- a/arch/x86/kernel/setup.c
++++ b/arch/x86/kernel/setup.c
+@@ -372,7 +372,6 @@ static void __init reserve_initrd(void)
+ 
+ 	printk(KERN_INFO "RAMDISK: [mem %#010llx-%#010llx]\n", ramdisk_image,
+ 			ramdisk_end - 1);
+-
+ 	if (pfn_range_is_mapped(PFN_DOWN(ramdisk_image),
+ 				PFN_DOWN(ramdisk_end))) {
+ 		/* All are mapped, easy case */
+@@ -541,6 +540,44 @@ static void __init reserve_crashkernel(void)
+ }
+ #endif
+ 
++#ifdef CONFIG_QUICK_KEXEC
++
++static void __init reserve_quick_kexec(void)
++{
++	int ret;
++	struct resource *res;
++	unsigned long long mem_len = 0;
++	unsigned long long mem_start = 0;
++
++	ret = parse_quick_kexec(boot_command_line, memblock_phys_mem_size(),
++			&mem_len, &mem_start);
++	if (ret || !mem_len)
++		return;
++
++	mem_start = memblock_find_in_range(CRASH_ALIGN,
++			CRASH_ADDR_HIGH_MAX,
++			mem_len,
++			CRASH_ALIGN);
++	if (mem_start == 0) {
++		pr_info("quick kexec reservation failed - memory is in use.\n");
++		return;
++	}
++
++	ret = memblock_reserve(mem_start, mem_len);
++	if (ret) {
++		pr_err("%s: Error reserving quick kexec memblock.\n", __func__);
++		return;
++	}
++
++	pr_info("Reserving %ldMB of memory for quick kexec\n",
++			(unsigned long)(mem_len >> 20));
++	res = &quick_kexec_res;
++	res->start = mem_start;
++	res->end = mem_start + mem_len - 1;
++	insert_resource(&iomem_resource, res);
++}
++#endif
++
+ static struct resource standard_io_resources[] = {
+ 	{ .name = "dma1", .start = 0x00, .end = 0x1f,
+ 		.flags = IORESOURCE_BUSY | IORESOURCE_IO },
+@@ -1143,6 +1180,9 @@ void __init setup_arch(char **cmdline_p)
+ 	 * won't consume hotpluggable memory.
+ 	 */
+ 	reserve_crashkernel();
++#ifdef CONFIG_QUICK_KEXEC
++	reserve_quick_kexec();
++#endif /* CONFIG_QUICK_KEXEC */
+ 
+ 	memblock_find_dma_reserve();
+ 
+-- 
+2.27.0
+
diff -Nur kernel/0004-x86-fix-early-boot-crash-on-gcc-10.patch obs_kernel/0004-x86-fix-early-boot-crash-on-gcc-10.patch
--- kernel/0004-x86-fix-early-boot-crash-on-gcc-10.patch	1970-01-01 08:00:00.000000000 +0800
+++ obs_kernel/0004-x86-fix-early-boot-crash-on-gcc-10.patch	2022-10-14 15:29:27.000000000 +0800
@@ -0,0 +1,71 @@
+From c2e15f6e797f36106a062f5e1e06734c3fd480f2 Mon Sep 17 00:00:00 2001
+From: Sergei Trofimovich <slyfox@gentoo.org>
+Date: Sat, 14 Mar 2020 16:44:51 +0000
+Subject: [PATCH 4/4] x86: fix early boot crash on gcc-10
+MIME-Version: 1.0
+Content-Type: text/plain; charset=UTF-8
+Content-Transfer-Encoding: 8bit
+
+The change fixes boot failure on physical machine where kernel
+is built with gcc-10 with stack-protector enabled by default:
+
+```
+Kernel panic — not syncing: stack-protector: Kernel stack is corrupted in: start_secondary+0x191/0x1a0
+CPU: 1 PID: 0 Comm: swapper/1 Not tainted 5.6.0-rc5—00235—gfffb08b37df9 #139
+Hardware name: Gigabyte Technology Co., Ltd. To be filled by O.E.M./H77M—D3H, BIOS F12 11/14/2013
+Call Trace:
+  dump_stack+0x71/0xa0
+  panic+0x107/0x2b8
+  ? start_secondary+0x191/0x1a0
+  __stack_chk_fail+0x15/0x20
+  start_secondary+0x191/0x1a0
+  secondary_startup_64+0xa4/0xb0
+-—-[ end Kernel panic — not syncing: stack—protector: Kernel stack is corrupted in: start_secondary+0x191
+```
+
+This happens because `start_secondary()` is responsible for setting
+up initial stack canary value in `smpboot.c`, but nothing prevents
+gcc from inserting stack canary into `start_secondary()` itself
+before `boot_init_stack_canary()` call.
+
+The fix passes `-fno-stack-protector` to avoid any early stack
+checks in `start_secondary()` or inlined functions into it.
+
+Tested the change by successfully booting the machine.
+
+A few similar crashes on VMs:
+- https://bugzilla.redhat.com/show_bug.cgi?id=1796780
+- http://rglinuxtech.com/?p=2694
+
+CC: Jakub Jelinek <jakub@redhat.com>
+CC: Thomas Gleixner <tglx@linutronix.de>
+CC: Ingo Molnar <mingo@redhat.com>
+CC: Borislav Petkov <bp@alien8.de>
+CC: "H. Peter Anvin" <hpa@zytor.com>
+CC: Andy Lutomirski <luto@kernel.org>
+CC: x86@kernel.org
+Signed-off-by: Sergei Trofimovich <slyfox@gentoo.org>
+---
+ arch/x86/kernel/Makefile | 6 ++++++
+ 1 file changed, 6 insertions(+)
+
+diff --git a/arch/x86/kernel/Makefile b/arch/x86/kernel/Makefile
+index 66835d9a6..fdfd97620 100644
+--- a/arch/x86/kernel/Makefile
++++ b/arch/x86/kernel/Makefile
+@@ -11,6 +11,12 @@ extra-y	+= vmlinux.lds
+ 
+ CPPFLAGS_vmlinux.lds += -U$(UTS_MACHINE)
+ 
++# smpboot's init_secondary initializes stack canary.
++# Make sure we don't emit stack checks before it's
++# initialized.
++nostackp := $(call cc-option, -fno-stack-protector)
++CFLAGS_smpboot.o := $(nostackp)
++
+ ifdef CONFIG_FUNCTION_TRACER
+ # Do not profile debug and lowlevel utilities
+ CFLAGS_REMOVE_tsc.o = -pg
+-- 
+2.27.0
+
diff -Nur kernel/0005-fix-multi-thread-recover-problem-with-pin-memory.patch obs_kernel/0005-fix-multi-thread-recover-problem-with-pin-memory.patch
--- kernel/0005-fix-multi-thread-recover-problem-with-pin-memory.patch	1970-01-01 08:00:00.000000000 +0800
+++ obs_kernel/0005-fix-multi-thread-recover-problem-with-pin-memory.patch	2022-10-16 17:46:55.000000000 +0800
@@ -0,0 +1,132 @@
+From 60b87f1f8c08bca48f2704e08f1cf0bedb00c69b Mon Sep 17 00:00:00 2001
+From: Jingxian He <hejingxian@huawei.com>
+Date: Fri, 14 Oct 2022 12:53:27 +0800
+Subject: [PATCH 1/1] fix multi thread recover problem with pin memory
+
+---
+ drivers/char/pin_memory.c | 27 +++++++++++++++++++++++++--
+ include/linux/pin_mem.h   |  2 ++
+ mm/pin_mem.c              | 32 ++++++++++++++++++++++++++++++++
+ 3 files changed, 59 insertions(+), 2 deletions(-)
+
+diff --git a/drivers/char/pin_memory.c b/drivers/char/pin_memory.c
+index e6ed26c18..962ba5abb 100644
+--- a/drivers/char/pin_memory.c
++++ b/drivers/char/pin_memory.c
+@@ -41,9 +41,11 @@ struct pin_mem_area_set {
+ #define _INIT_PAGEMAP_READ   5
+ #ifdef CONFIG_PID_RESERVE
+ #define _SET_FORK_PID        6
+-#define _PIN_MEM_IOC_MAX_NR  6
++#define _CLEAR_TASK_OUTDATED_STATE  7
++#define _PIN_MEM_IOC_MAX_NR  7
+ #else
+-#define _PIN_MEM_IOC_MAX_NR  5
++#define _CLEAR_TASK_OUTDATED_STATE  6
++#define _PIN_MEM_IOC_MAX_NR  6
+ #endif
+ #define SET_PIN_MEM_AREA        _IOW(PIN_MEM_MAGIC, _SET_PIN_MEM_AREA, struct pin_mem_area_set)
+ #define CLEAR_PIN_MEM_AREA      _IOW(PIN_MEM_MAGIC, _CLEAR_PIN_MEM_AREA, int)
+@@ -53,6 +55,8 @@ struct pin_mem_area_set {
+ #ifdef CONFIG_PID_RESERVE
+ #define SET_FORK_PID            _IOW(PIN_MEM_MAGIC, _SET_FORK_PID, int)
+ #endif
++#define CLEAR_TASK_OUTDATED_STATE       _IOW(PIN_MEM_MAGIC, _CLEAR_TASK_OUTDATED_STATE, int)
++
+ static int set_pin_mem(struct pin_mem_area_set *pmas)
+ {
+ 	int i;
+@@ -164,9 +168,22 @@ fault:
+ }
+ #endif
+ 
++static int get_input_pid(unsigned long arg)
++{
++	int pid;
++	void __user *buf = (void __user *)arg;
++
++	if (!access_ok(buf, sizeof(int)))
++		return -EINVAL;
++	if (copy_from_user(&pid, buf, sizeof(int)))
++		return -EINVAL;
++	return pid;
++}
++
+ static long pin_memory_ioctl(struct file *file, unsigned int cmd, unsigned long arg)
+ {
+ 	long ret = 0;
++	pid_t pid;
+ 
+ 	if (_IOC_TYPE(cmd) != PIN_MEM_MAGIC)
+ 		return -EINVAL;
+@@ -194,6 +211,12 @@ static long pin_memory_ioctl(struct file *file, unsigned int cmd, unsigned long
+ 		ret = set_fork_pid(arg);
+ 		break;
+ #endif
++	case CLEAR_TASK_OUTDATED_STATE:
++		pid = get_input_pid(arg);
++		if (pid < 0)
++			return -EINVAL;
++		ret = clear_task_outdated_state(pid);
++		break;
+ 	default:
+ 		return -EINVAL;
+ 	}
+diff --git a/include/linux/pin_mem.h b/include/linux/pin_mem.h
+index 6c54482a4..e2ec5a0b5 100644
+--- a/include/linux/pin_mem.h
++++ b/include/linux/pin_mem.h
+@@ -95,5 +95,7 @@ extern void free_reserved_pid(struct idr *idr, int pid);
+ extern void reserve_pids(struct idr *idr, int pid_max);
+ #endif
+ 
++extern int clear_task_outdated_state(int pid);
++
+ #endif /* CONFIG_PIN_MEMORY */
+ #endif /* _LINUX_PIN_MEMORY_H */
+diff --git a/mm/pin_mem.c b/mm/pin_mem.c
+index d03593472..e27cebb1f 100644
+--- a/mm/pin_mem.c
++++ b/mm/pin_mem.c
+@@ -1096,6 +1096,38 @@ void clear_pin_memory_record(void)
+ }
+ EXPORT_SYMBOL_GPL(clear_pin_memory_record);
+ 
++int clear_task_outdated_state(int pid)
++{
++	int ret = -ESRCH;
++	struct task_struct *task;
++
++	rcu_read_lock();
++	task = find_task_by_vpid(pid);
++	if (!task) {
++		pr_warn("%s: task struct is null.\n", __func__);
++		goto out;
++	}
++
++	/* If `task->clear_child_tid` wasn't NULL, syscall `exit()` will assign 0 to
++	 * its memory. It's unexpecting action when we using pin memory. Just assign
++	 * NULL here to prevent the above.
++	 *
++	 * The `task->{robust_list, compat_robust_list}` is the same as
++	 * `task->clear_child_tid`.
++	 */
++	task->clear_child_tid = NULL;
++	task->robust_list = NULL;
++#ifdef CONFIG_COMPAT
++	task->compat_robust_list = NULL;
++#endif
++	ret = 0;
++
++out:
++	rcu_read_unlock();
++	return ret;
++}
++EXPORT_SYMBOL_GPL(clear_task_outdated_state);
++
+ #ifdef CONFIG_PID_RESERVE
+ struct idr *reserve_idr;
+ 
+-- 
+2.27.0
+
diff -Nur kernel/SOURCE obs_kernel/SOURCE
--- kernel/SOURCE	2022-11-04 11:19:14.458579086 +0800
+++ obs_kernel/SOURCE	2022-10-16 17:33:41.000000000 +0800
@@ -1 +1 @@
-4.19.90-2211.1.0
+4.19.90-2210.1.0
diff -Nur kernel/kernel.spec obs_kernel/kernel.spec
--- kernel/kernel.spec	2022-11-04 11:19:14.462579134 +0800
+++ obs_kernel/kernel.spec	2022-10-25 02:40:37.000000000 +0800
@@ -12,7 +12,7 @@
 
 %global KernelVer %{version}-%{release}.%{_target_cpu}
 
-%global hulkrelease 2211.1.0
+%global hulkrelease 2112.8.0
 
 %define with_patch 0
 
@@ -32,7 +32,7 @@
 
 Name:	 kernel
 Version: 4.19.90
-Release: %{hulkrelease}.0175
+Release: %{hulkrelease}.0132
 Summary: Linux Kernel
 License: GPLv2
 URL:	 http://www.kernel.org/
@@ -60,6 +60,16 @@
 Source9998: patches.tar.bz2
 %endif
 
+Patch0001: 0001-kexec-provide-generic-quick-kexec-cmdline-parsing-AP.patch
+Patch0002: 0002-arm64-change-quick-memory-parsing-API.patch
+Patch0003: 0003-x86-add-support-for-quick-kexec.patch
+Patch0004: 0004-x86-fix-early-boot-crash-on-gcc-10.patch
+Patch0005: 0005-fix-multi-thread-recover-problem-with-pin-memory.patch
+Patch0006: 0001-pinmem-fix-build.patch
+Patch0007: 0001-disable-some-kconfig-for-unixbench.patch
+Patch0008: 0001-kconfig-enable-pin-memory-and-quick-kexec-for-x86.patch
+Patch0009: 0001-bpf-bpftool-add-support-for-attaching-programs-to-ma.patch
+
 #BuildRequires:
 BuildRequires: module-init-tools, patch >= 2.5.4, bash >= 2.03, tar
 BuildRequires: bzip2, xz, findutils, gzip, m4, perl, make >= 3.78, diffutils, gawk
@@ -275,6 +285,16 @@
 cp -a tools/perf tools/python3-perf
 %endif
 
+%patch0001 -p1
+%patch0002 -p1
+%patch0003 -p1
+%patch0004 -p1
+%patch0005 -p1
+%patch0006 -p1
+%patch0007 -p1
+%patch0008 -p1
+%patch0009 -p1
+
 %build
 cd linux-%{KernelVer}
 
@@ -294,7 +314,7 @@
 %if 0%{?with_kabichk}
     chmod 0755 %{SOURCE18}
     if [ -e $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu} ]; then
-        %{SOURCE18} -k $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu} -s Module.symvers || exit 1
+        #%%{SOURCE18} -k $RPM_SOURCE_DIR/Module.kabi_%%{_target_cpu} -s Module.symvers || exit 1
 	echo "**** NOTE: now don't check Kabi. ****"
     else
         echo "**** NOTE: Cannot find reference Module.kabi file. ****"
@@ -664,18 +684,18 @@
 fi
 
 %posttrans
-%{_sbindir}/new-kernel-pkg --package kernel --mkinitrd --dracut --depmod --update %{KernelVer} || exit $?
-%{_sbindir}/new-kernel-pkg --package kernel --rpmposttrans %{KernelVer} || exit $?
+%{_sbindir}/new-kernel-pkg --package kernel --mkinitrd --dracut --depmod --update %{KernelVer}
+%{_sbindir}/new-kernel-pkg --package kernel --rpmposttrans %{KernelVer}
 if [ `uname -i` == "aarch64" ] &&
         [ -f /boot/EFI/grub2/grub.cfg ]; then
 	/usr/bin/sh %{_sbindir}/mkgrub-menu-%{hulkrelease}.sh %{version}-%{hulkrelease}.aarch64  /boot/EFI/grub2/grub.cfg  update  
 fi
-if [ -x %{_sbindir}/weak-modules ]
-then
-    %{_sbindir}/weak-modules --add-kernel %{KernelVer} || exit $?
-fi
-%{_sbindir}/new-kernel-pkg --package kernel --mkinitrd --dracut --depmod --update %{KernelVer} || exit $?
-%{_sbindir}/new-kernel-pkg --package kernel --rpmposttrans %{KernelVer} || exit $?
+#if [ -x %%{_sbindir}/weak-modules ]
+#then
+#    %%{_sbindir}/weak-modules --add-kernel %%{KernelVer} || exit $?
+#fi
+%{_sbindir}/new-kernel-pkg --package kernel --mkinitrd --dracut --depmod --update %{KernelVer}
+%{_sbindir}/new-kernel-pkg --package kernel --rpmposttrans %{KernelVer}
 
 
 %post devel
@@ -809,1445 +829,8 @@
 
 %changelog
 
-* Wed Nov 02 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2211.1.0.0175
-- uacce: add the reference counter protection
-- nilfs2: fix NULL pointer dereference at nilfs_bmap_lookup_at_level()
-- usb: mon: make mmapped memory read only
-- !185 [openEuler-1.0-LTS] Add support sata lpm for Zhaoxin CPUs
-- ext4: fix bug_on in __es_tree_search caused by bad boot loader inode
-- ext4: add EXT4_IGET_BAD flag to prevent unexpected bad inode
-- ext4: add helper to check quota inums
-- ext4: fix bug_on in __es_tree_search caused by bad quota inode
-- atm: idt77252: fix use-after-free bugs caused by tst_timer
-- ext4: ext4_read_bh_lock() should submit IO if the buffer isn't uptodate
-- !94 [openEuler-1.0-LTS] rtc: Fix set RTC time delay 500ms on some Zhaoxin SOCs
-- !88 [openEuler-1.0-LTS] XHCI:Fix some device identify fail when enable xHCI runtime suspend
-- !92 [openEuler-1.0-LTS] x86/tsc: Make cur->adjusted values in package#1 to be the same
-- !93 [openEuler-1.0-LTS] Driver for Zhaoxin CPU core temperature monitoring
-- !89 [openEuler-1.0-LTS] EHCI: Clear wakeup signal locked in S0  state when device plug in
-- scsi: stex: Properly zero out the passthrough command structure
-- !192 x86/apic/vector: Fix ordering in vector assignment
-- nilfs2: fix leak of nilfs_root in case of writer thread creation failure
-- vsock: Fix memory leak in vsock_connect()
-- x86/apic/vector: Fix ordering in vector assignment
-- Add support for PxSCT.LPM set based on actual LPM circumstances
-- Add support for disabling PhyRdy Change Interrupt based on actual LPM capability
-- Driver for Zhaoxin CPU core temperature monitoring
-- rtc: Fix set RTC time delay 500ms on some Zhaoxin SOCs
-- x86/tsc: Make cur->adjusted values in package#1 to be the same
-- EHCI: Clear wakeup signal locked in S0 state when device plug in
-- XHCI:Fix some device identify fail when enable xHCI runtime suspend
-
-* Thu Oct 27 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2210.5.0.0174
-- sch_sfb: Also store skb len before calling child enqueue
-- sch_sfb: Don't assume the skb is still around after enqueueing to child
-- ipv6: Fix data races around sk->sk_prot.
-- ipv6: annotate some data-races around sk->sk_prot
-- ipv6: provide and use ipv6 specific version for {recv, send}msg
-- inet: factor out inet_send_prepare()
-- nilfs2: fix use-after-free bug of struct nilfs_root
-
-* Tue Oct 25 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2210.4.0.0173
-- nfp: fix use-after-free in area_cache_get()
-- mISDN: fix use-after-free bugs in l1oip timer handlers
-- tcp: Fix data races around icsk->icsk_af_ops.
-- Bluetooth: L2CAP: Fix use-after-free caused by l2cap_reassemble_sdu
-- !134 scsi: megaraid_sas: Add support for MegaRAID Aero controllers
-- !138 vfio-pci: Mask cap zero
-- bnx2x: fix potential memory leak in bnx2x_tpa_stop()
-- r8152: Rate limit overflow messages
-- scsi: megaraid_sas: Add support for MegaRAID Aero controllers
-- vfio-pci: Mask cap zero
-- tcp/udp: Fix memory leak in ipv6_renew_options().
-- net: mvpp2: fix mvpp2 debugfs leak
-- !159 PCI: Add ACS quirk for Broadcom NICs
-- !137 net: bonding: Add support for IPV6 ns/na to balance-alb/balance-tlb mode
-- kcm: avoid potential race in kcm_tx_work
-- net: bonding: Add support for IPV6 ns/na to balance-alb/balance-tlb mode
-- !139 nvme: Assign subsys instance from first ctrl
-- fbdev: smscufx: Fix use-after-free in ufx_ops_open()
-- nvme: fix controller instance leak
-- nvme: Assign subsys instance from first ctrl
-- PCI: Add ACS quirk for Broadcom BCM5750x NICs
-- PCI: Add ACS quirk for Broadcom BCM57414 NIC
-
-* Tue Oct 18 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2210.3.0.0172
-- binder: fix UAF of ref->proc caused by race condition
-- arm64: fix oops in concurrently setting insn_emulation sysctls
-- mm/hotplug: silence a lockdep splat with printk()
-- init/Kconfig: Add SMP to the dependencies of QOS_SCHED
-- mm/rmap: Fix kabi broken in anon_vma
-- mm/rmap: Fix anon_vma->degree ambiguity leading to double-reuse
-- HID: roccat: Fix use-after-free in roccat_read()
-- ext4: fix dir corruption when ext4_dx_add_entry() fails
-- quota: Add more checking after reading from quota file
-- quota: Replace all block number checking with helper function
-- quota: Check next/prev free block number after reading from quota file
-- Revert "quota: Check next/prev free block number after reading from quota file"
-- Revert "quota: Replace all block number checking with helper function"
-- Revert "quota: Add more checking after reading from quota file"
-- tracefs: Only clobber mode/uid/gid on remount if asked
-- netfilter: ebtables: fix memory leak when blob is malformed
-- netfilter: ebtables: reject blobs that don't provide all entry points
-- mm: Fix TLB flush for not-first PFNMAP mappings in unmap_region()
-- SUNRPC: use _bh spinlocking on ->transport_lock
-- tcp: fix early ETIMEDOUT after spurious non-SACK RTO
-- netfilter: br_netfilter: Drop dst references before setting.
-- debugfs: add debugfs_lookup_and_remove()
-- tcp: annotate data-race around challenge_timestamp
-- Revert "mm: kmemleak: take a full lowmem check in kmemleak_*_phys()"
-- net: neigh: don't call kfree_skb() under spin_lock_irqsave()
-- neigh: fix possible DoS due to net iface start/stop loop
-- mm/hugetlb: fix hugetlb not supporting softdirty tracking
-- asm-generic: sections: refactor memory_intersects
-- loop: Check for overflow while configuring loop
-- net: Fix a data-race around sysctl_somaxconn.
-- net: Fix a data-race around netdev_budget_usecs.
-- net: Fix a data-race around netdev_budget.
-- net: Fix a data-race around sysctl_net_busy_read.
-- net: Fix a data-race around sysctl_net_busy_poll.
-- net: Fix a data-race around sysctl_tstamp_allow_data.
-- ratelimit: Fix data-races in ___ratelimit().
-- net: Fix data-races around netdev_tstamp_prequeue.
-- net: Fix data-races around weight_p and dev_weight_[rt]x_bias.
-- net: ipvtap - add __init/__exit annotations to module init/exit funcs
-- bonding: 802.3ad: fix no transmission of LACPDUs
-- xfrm: fix refcount leak in __xfrm_policy_check()
-- audit: fix potential double free on error path from fsnotify_add_inode_mark
-- dm: return early from dm_pr_call() if DM device is suspended
-- NFSv4: Fix races in the legacy idmapper upcall
-
-* Tue Oct 11 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2210.1.0.0171
-- netfilter: nf_conntrack_irc: Fix forged IP logic
-- ext4: fix check for block being out of directory size
-- ext4: check if directory block is within i_size
-- block: Fix UAF in bd_link_disk_holder()
-- ALSA: pcm: oss: Fix race at SNDCTL_DSP_SYNC
-- block: add a new config to control dispatching bios asynchronously
-- block: fix kabi broken in request_queue
-- md: enable dispatching bio asynchronously for raid10 by default
-- arm64/topology: getting preferred sibling's cpumask supported by platform
-- block: support to dispatch bio asynchronously
-- block: add new fields in request_queue
-- md/raid10: convert resync_lock to use seqlock
-- md/raid10: prevent unnecessary calls to wake_up() in fast path
-- !122 【kernel-openEuler-1.0-LTS】kernel：fix some issues with 4.19 kernel on openEuler 22.03 system
-- mm: sharepool: fix potential AA deadlock
-- mm: sharepool: check size=0 in mg_sp_make_share_k2u()
-- mm: sharepool: delete redundant check in __sp_remap_get_pfn
-- Revert "cifs: fix double free race when mount fails in cifs_get_root()"
-- scsi: hisi_sas: Release resource directly in hisi_sas_abort_task() when NCQ error
-- scsi: hisi_sas: Enable force phy when SATA disk directly connected
-- scsi: hisi_sas: Modify v3 HW ATA completion process when SATA disk is in error status
-- sched: Fix invalid free for tsk->se.dyn_affi_stats
-- scsi: target: tcmu: Fix warning: 'page' may be used uninitialized
-- scsi: target: tcmu: Fix crash on ARM during cmd completion
-- scsi: target: tcmu: Optimize use of flush_dcache_page
-- scsi: target: tcmu: Fix size in calls to tcmu_flush_dcache_range
-- signal: fix deadlock caused by calling printk() under sighand->siglock
-- mm: fix missing handler for __GFP_NOWARN
-- perf bench futex-wake: Restore thread count default to online CPU count
-- selftests/bpf: Enlarge select() timeout for test_maps
-- xfs: preserve default grace interval during quotacheck
-- i40e: Fix kernel crash during module removal
-- i40e: Fix use-after-free in i40e_client_subtask()
-- EDAC: skx_common: downgrade message importance on missing PCI device
-- x86/entry/64: Don't compile ignore_sysret if 32-bit emulation is enabled
-- x86: Fix early boot crash on gcc-10, third try
-- objtool: Don't fail on missing symbol table
-
-* Tue Sep 27 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2209.6.0.0170
-- KVM: x86/pmu: Update AMD PMC sample period to fix guest NMI-watchdog
-- KVM: x86: Adjust counter sample period after a wrmsr
-- KVM: x86: Fix perfctr WRMSR for running counters
-- perf/core: Provide a kernel-internal interface to recalibrate event period
-- media: em28xx: initialize refcount before kref_get
-- mm: avoid potential deadlock tirgged by writing slab-attr-file
-- ext4: fix use-after-free in ext4_ext_shift_extents
-- quota: Add more checking after reading from quota file
-- quota: Replace all block number checking with helper function
-- quota: Check next/prev free block number after reading from quota file
-- efi: capsule-loader: Fix use-after-free in efi_capsule_write
-- ipvlan: Fix out-of-bound bugs caused by unset skb->mac_header
-- mm/sharepool: Fix UAF reported by KASAN
-- blk-mq: avoid extending delays of active hctx from blk_mq_delay_run_hw_queues
-- mm: mem_reliable: Start fallback if no suitable zone found
-- net: hns3: update hns3 version to 22.9.2
-- net: hns3: fix error resume keep alive when remove hclgevf
-- net: hns3: update hns3 version to 22.9.1
-- net: hns3: fix keep alive can not resume problem when system busy
-
-* Tue Sep 20 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2209.5.0.0169
-- jfs: prevent NULL deref in diFree
-- jfs: fix GPF in diFree
-
-* Thu Sep 15 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2209.4.0.0168
-- mm: Force TLB flush for PFNMAP mappings before unlink_file_vma()
-- video: fbdev: pxa3xx-gcu: Fix integer overflow in pxa3xx_gcu_write
-
-* Wed Sep 14 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2209.3.0.0167
-- KVM: x86: do not report a vCPU as preempted outside instruction boundaries
-- KVM: arm64: Write arch.mdcr_el2 changes since last vcpu_load on VHE
-- netfilter: nf_conntrack_irc: Tighten matching on DCC message
-- ext4: avoid resizing to a partial cluster size
-- locking/atomic: Make test_and_*_bit() ordered on failure
-- geneve: do not use RT_TOS for IPv6 flowlabel
-- SUNRPC: Reinitialise the backchannel request buffers before reuse
-- NFSv4/pnfs: Fix a use-after-free bug in open
-- NFSv4.1: RECLAIM_COMPLETE must handle EACCES
-- tcp: fix over estimation in sk_forced_mem_schedule()
-- ext4: fix extent status tree race in writeback error recovery path
-- ext4: update s_overhead_clusters in the superblock during an on-line resize
-- ext4: make sure ext4_append() always allocates new block
-- kprobes: Forbid probing on trampoline and BPF code areas
-- kfifo: fix kfifo_to_user() return type
-- profiling: fix shift too large makes kernel panic
-- serial: 8250_dw: Store LSR into lsr_saved_flags in dw8250_tx_wait_empty()
-- mm/mmap.c: fix missing call to vm_unacct_memory in mmap_region
-- mtd: st_spi_fsm: Add a clk_disable_unprepare() in .probe()'s error path
-- mtd: sm_ftl: Fix deadlock caused by cancel_work_sync in sm_release
-- can: error: specify the values of data[5..7] of CAN error frames
-- fs: check FMODE_LSEEK to control internal pipe splicing
-- tcp: make retransmitted SKB fit into the send window
-- nohz/full, sched/rt: Fix missed tick-reenabling bug in dequeue_task_rt()
-- bus: hisi_lpc: fix missing platform_device_put() in hisi_lpc_acpi_probe()
-- x86/pmem: Fix platform-device leak in error path
-- selinux: Add boundary check in put_entry()
-- ACPI: LPSS: Fix missing check in register_device_clock()
-- fs: Add missing umask strip in vfs_tmpfile
-- vfs: Check the truncate maximum size in inode_newsize_ok()
-- tcp: Fix a data-race around sysctl_tcp_comp_sack_nr.
-- tcp: Fix a data-race around sysctl_tcp_comp_sack_delay_ns.
-- tcp: Fix a data-race around sysctl_tcp_invalid_ratelimit.
-- tcp: Fix a data-race around sysctl_tcp_autocorking.
-- tcp: Fix a data-race around sysctl_tcp_min_rtt_wlen.
-- tcp: Fix a data-race around sysctl_tcp_min_tso_segs.
-- igmp: Fix data-races around sysctl_igmp_qrv.
-- net: ping6: Fix memleak in ipv6_renew_options().
-- tcp: Fix a data-race around sysctl_tcp_challenge_ack_limit.
-- tcp: Fix a data-race around sysctl_tcp_nometrics_save.
-- tcp: Fix a data-race around sysctl_tcp_frto.
-- tcp: Fix a data-race around sysctl_tcp_adv_win_scale.
-- tcp: Fix a data-race around sysctl_tcp_app_win.
-- tcp: Fix data-races around sysctl_tcp_dsack.
-- mm/mempolicy: fix uninit-value in mpol_rebind_policy()
-- tcp: Fix data-races around sysctl_tcp_max_reordering.
-- tcp: Fix a data-race around sysctl_tcp_rfc1337.
-- tcp: Fix a data-race around sysctl_tcp_stdurg.
-- tcp: Fix a data-race around sysctl_tcp_retrans_collapse.
-- tcp: Fix data-races around sysctl_tcp_slow_start_after_idle.
-- tcp: Fix a data-race around sysctl_tcp_thin_linear_timeouts.
-- tcp: Fix data-races around sysctl_tcp_recovery.
-- tcp: Fix a data-race around sysctl_tcp_early_retrans.
-- tcp: Fix data-races around sysctl_tcp_fastopen.
-- tcp: Fix a data-race around sysctl_tcp_tw_reuse.
-- tcp: Fix a data-race around sysctl_tcp_notsent_lowat.
-- tcp: Fix data-races around some timeout sysctl knobs.
-- tcp: Fix data-races around sysctl_tcp_reordering.
-- igmp: Fix a data-race around sysctl_igmp_max_memberships.
-- igmp: Fix data-races around sysctl_igmp_llm_reports.
-- tcp: Fix a data-race around sysctl_tcp_probe_interval.
-- tcp: Fix a data-race around sysctl_tcp_probe_threshold.
-- tcp: Fix data-races around sysctl_tcp_mtu_probing.
-- tcp/dccp: Fix a data-race around sysctl_tcp_fwmark_accept.
-- ip: Fix a data-race around sysctl_fwmark_reflect.
-- ip: Fix data-races around sysctl_ip_nonlocal_bind.
-- ip: Fix data-races around sysctl_ip_fwd_use_pmtu.
-- block: fix the problem of io_ticks becoming smaller
-- blk-mq: Fix memory leak in blk_mq_init_allocated_queue error handling
-- block, bfq: save & resume weight on a queue merge/split
-- ACPICA: Disassembler: create buffer fields in ACPI_PARSE_LOAD_PASS1
-- acpi/nfit: improve bounds checking for 'func'
-- ACPICA: Do not increment operation_region reference counts for field units
-- ACPICA: Fix exception code class checks
-- ACPI: configfs: add missing check after configfs_register_default_group()
-- ACPI: custom_method: fix potential use-after-free issue
-- ACPI: custom_method: fix a possible memory leak
-- ACPI: APD: Check for NULL pointer after calling devm_ioremap()
-- ACPI/IORT: Fix PMCG node single ID mapping handling
-- ACPI/IORT: Check node revision for PMCG resources
-- kprobes: don't call disarm_kprobe() for disabled kprobes
-- x86/unwind/orc: Unwind ftrace trampolines with correct ORC entry
-- usb: gadget: function: printer: fix use-after-free in __lock_acquire
-- video: fbdev: i740fb: Error out if 'pixclock' equals zero
-- lightnvm: disable the subsystem
-- configfs: fix a race in configfs_lookup()
-- configfs: fold configfs_attach_attr into configfs_lookup
-- configfs: make configfs_create() return inode
-- configfs: factor dirent removal into helpers
-- configfs: simplify the configfs_dirent_is_ready
-- configfs: return -ENAMETOOLONG earlier in configfs_lookup
-
-* Mon Sep 05 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2209.1.0.0166
-- dm-thin: Resume failed in FAIL mode
-- tpm: fix reference counting for struct tpm_chip
-- af_key: Do not call xfrm_probe_algs in parallel
-- net: usb: ax88179_178a: Fix packet receiving
-- net: usb: ax88179_178a: Fix out-of-bounds accesses in RX fixup
-- net: usb: ax88179_178a: fix packet alignment padding
-
-* Mon Aug 29 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2208.6.0.0165
-- tty: use new tty_insert_flip_string_and_push_buffer() in pty_write()
-- tty: extract tty_flip_buffer_commit() from tty_flip_buffer_push()
-- tty: drop tty_schedule_flip()
-- tty: the rest, stop using tty_schedule_flip()
-- tty: drivers/tty/, stop using tty_schedule_flip()
-- can: bcm/raw/isotp: use per module netdevice notifier
-- CIFS: Fix retry mid list corruption on reconnects
-- KVM: arm64: vgic-its: Change default outer cacheability for {PEND, PROP}BASER
-- xhci: Fix a logic issue when display Zhaoxin XHCI root hub speed
-- dm verity: set DM_TARGET_IMMUTABLE feature flag
-- scsi: hisi_sas: Add SATA_DISK_ERR bit handling for v3 hw
-- Revert "scsi: hisi_sas: Modify v3 HW I/O processing when SATA_DISK_ERR bit is set and NCQ Error occurs"
-- netfilter: nf_tables: do not allow RULE_ID to refer to another chain
-- netfilter: nf_tables: do not allow SET_ID to refer to another table
-
-* Mon Aug 22 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2208.5.0.0164
-- x86/speculation: Add LFENCE to RSB fill sequence
-- x86/speculation: Add RSB VM Exit protections
-- Revert "blk-mq: fix null pointer dereference in blk_mq_queue_tag_busy_ite"
-- blk-mq: fix null pointer dereference in blk_mq_queue_tag_busy_ite
-- arm64: Avoid premature usercopy failure for __arch_copy_to_user_generic_read
-- net_sched: cls_route: remove from list when handle is 0
-
-* Mon Aug 15 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2208.4.0.0163
-- Revert "x86/unwind/orc: Change REG_SP_INDIRECT"
-- Phytium/S2500: kdump: Avoid vmcore saving failure across multi-socket
-- PCI: Add config control for phytium ACS quirks
-- scsi: libiscsi: Teardown iscsi_cls_conn gracefully
-- scsi: libiscsi: Add iscsi_cls_conn to sysfs after initialization
-- scsi: iscsi: Add helper functions to manage iscsi_cls_conn
-- media: v4l2-mem2mem: Apply DST_QUEUE_OFF_BASE on MMAP buffers across ioctls
-- sched: Fix null-ptr-deref in free_fair_sched_group
-- RDMA/ib_srp: Fix a deadlock
-- mm/slub: add missing TID updates on slab deactivation
-- block: fix regression for dm
-- blk-mq: handle bio after queue is initialized
-- x86: Clear .brk area at early boot
-- signal/seccomp: Dump core when there is only one live thread
-- x86/unwind/orc: Recheck address range after stack info was updated
-- x86/unwind/orc: Silence warnings caused by missing ORC data
-- x86/unwind/orc: Change REG_SP_INDIRECT
-
-* Tue Aug 09 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2208.2.0.0162
-- netfilter: nf_queue: do not allow packet truncation below transport header offset
-- openvswitch: fix OOB access in reserve_sfa_size()
-- dm thin: use refcount_t for thin_c reference counting
-- exec: Force single empty string when argv is empty
-- usb: gadget: rndis: prevent integer overflow in rndis_set_response()
-- serial: pl011: UPSTAT_AUTORTS requires .throttle/unthrottle
-- serial: 8250: fix return error code in serial8250_request_std_resource()
-- ipv4: Fix data-races around sysctl_ip_dynaddr.
-- icmp: Fix a data-race around sysctl_icmp_ratemask.
-- icmp: Fix a data-race around sysctl_icmp_ratelimit.
-- icmp: Fix data-races around sysctl.
-- net: Fix data-races around sysctl_mem.
-- inetpeer: Fix data-races around sysctl.
-- usbnet: fix memory leak in error case
-- esp: limit skb_page_frag_refill use to a single page
-- net: tun: avoid disabling NAPI twice
-- net: bonding: fix use-after-free after 802.3ad slave unbind
-- net: bonding: fix possible NULL deref in rlb code
-- usbnet: fix memory allocation in helpers
-- net: tun: stop NAPI when detaching queues
-- net: tun: unlink NAPI from device on destruction
-- virtio-net: fix race between ndo_open() and virtio_device_ready()
-- SUNRPC: Fix READ_PLUS crasher
-- virtio_net: fix xdp_rxq_info bug after suspend/resume
-- erspan: do not assume transport header is always set
-- net/sched: sch_netem: Fix arithmetic in netem_dump() for 32-bit platforms
-- bonding: ARP monitor spams NETDEV_NOTIFY_PEERS notifiers
-- ext4: make variable "count" signed
-- serial: 8250: Store to lsr_save_flags after lsr read
-- irqchip/gic-v3: Fix refcount leak in gic_populate_ppi_partitions
-- irqchip/gic/realview: Fix refcount leak in realview_gic_of_init
-- ata: libata-core: fix NULL pointer deref in ata_host_alloc_pinfo()
-- ipv6/addrconf: fix a null-ptr-deref bug for ip6_ptr
-- io_uring: add missing item types for various requests
-- net/sched: cls_u32: fix possible leak in u32_init_knode()
-- fq_codel: reject silly quantum parameters
-- net: sched: sch_teql: fix null-pointer dereference
-- rcu: Set a maximum limit for back-to-back callback invocation
-- mm: Fix page counter mismatch in shmem_mfill_atomic_pte
-- scsi: mpt3sas: Fix unlock imbalance
-- io-wq: Switch io_wqe_worker's fs before releasing request
-- ath9k: fix use-after-free in ath9k_hif_usb_rx_cb
-- Revert "iommu/vt-d: Fix potential memory leak in intel_setup_irq_remapping()"
-
-* Tue Aug 02 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2208.1.0.0161
-- fbcon: Prevent that screen size is smaller than font size
-- fbcon: Disallow setting font bigger than screen size
-- fbmem: Check virtual screen sizes in fb_set_var()
-- xfrm: xfrm_policy: fix a possible double xfrm_pols_put() in xfrm_bundle_lookup()
-- scsi: core: Fix race between handling STS_RESOURCE and completion
-- block: prevent lockdep false positive warning about 'bd_mutex'
-- dm verity: allow only one error handling mode
-- dm verity: Fix compilation warning
-- dm verity: add root hash pkcs#7 signature verification
-- jbd2: Fix assertion 'jh->b_frozen_data == NULL' failure when journal aborted
-- dm btree spine: show warning if node_check failed in node_prep_for_write()
-- dm btree spine: remove paranoid node_check call in node_prep_for_write()
-- ext4: Fix race when reusing xattr blocks
-- ext4: Unindent codeblock in ext4_xattr_block_set()
-- ext4: Remove EA inode entry from mbcache on inode eviction
-- mbcache: Add functions to delete entry if unused
-- mbcache: Don't reclaim used entries
-- perf/core: Fix data race between perf_event_set_output() and perf_mmap_close()
-
-* Mon Jul 25 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2207.4.0.0160
-- inotify: show inotify mask flags in proc fdinfo
-- io_uring: always grab file table for deferred statx
-- bpf: Don't redirect packets with invalid pkt_len
-- config: enable CONFIG_QOS_SCHED_DYNAMIC_AFFINITY by default
-- sched: Add statistics for scheduler dynamic affinity
-- sched: Adjust cpu range in load balance dynamicly
-- sched: Adjust wakeup cpu range according CPU util dynamicly
-- cpuset: Introduce new interface for scheduler dynamic affinity
-- sched: Introduce dynamic affinity for cfs scheduler
-- crypto: hisilicon/sec - don't sleep when in softirq
-- video: fbdev: sm712fb: Fix crash in smtcfb_write()
-- video: fbdev: sm712fb: Fix crash in smtcfb_read()
-- scsi: ses: fix slab-out-of-bounds in ses_enclosure_data_process
-- block: don't delete queue kobject before its children
-- etmem:fix kernel stack overflow in do_swapcache_reclaim
-- etmem:fix kasan slab-out-of-bounds in do_swapcache_reclaim
-- nbd: don't clear 'NBD_CMD_INFLIGHT' flag if request is not completed
-- blk-throttle: fix io hung due to configuration updates
-- block: fix NULL pointer dereference in disk_release()
-- block, bfq: make bfq_has_work() more accurate
-- blk-mq: fix panic during blk_mq_run_work_fn()
-- blk-mq: cancel blk-mq dispatch work in both blk_cleanup_queue and disk_release()
-- blk-mq: move cancel of hctx->run_work to the front of blk_exit_queue
-- ext4: fix race condition between ext4_ioctl_setflags and ext4_fiemap
-
-* Mon Jul 18 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2207.3.0.0159
-- block: fix that part scan is disabled in device_add_disk()
-- Revert "block: rename bd_invalidated"
-- Revert "block: move the NEED_PART_SCAN flag to struct gendisk"
-- Revert "block:Fix kabi broken"
-- rcu/tree: Mark functions as notrace
-- netfilter: nf_tables: stricter validation of element data
-- net: rose: fix UAF bugs caused by timer handler
-- xen/arm: Fix race in RB-tree based P2M accounting
-- vt: drop old FONT ioctls
-- dm thin: Fix crash in dm_sm_register_threshold_callback()
-- xen/blkfront: force data bouncing when backend is untrusted
-- xen/netfront: force data bouncing when backend is untrusted
-- xen-netfront: fix potential deadlock in xennet_remove()
-- xen/netfront: fix leaking data in shared pages
-- xen/blkfront: fix leaking data in shared pages
-- xen/blkfront: fix memory allocation flags in blkfront_setup_indirect()
-- tmpfs: fix the issue that the mount and remount results are inconsistent.
-- tmpfs: fix undefined-behaviour in shmem_reconfigure()
-- mm/sharepool: Check sp_is_enabled() before show spa_stat
-
-* Mon Jul 11 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2207.2.0.0158
-- x86: Fix return value of __setup handlers
-- x86/delay: Fix the wrong asm constraint in delay_loop()
-- ACPI: sysfs: Fix BERT error region memory mapping
-- tcp: fix tcp_mtup_probe_success vs wrong snd_cwnd
-- nbd: fix io hung while disconnecting device
-- nbd: fix race between nbd_alloc_config() and module removal
-- nbd: call genl_unregister_family() first in nbd_cleanup()
-- ip_gre: test csum_start instead of transport header
-- net: xfrm: unexport __init-annotated xfrm4_protocol_init()
-- SUNRPC: Fix the calculation of xdr->end in xdr_get_next_encode_buffer()
-- af_unix: Fix a data-race in unix_dgram_peer_wake_me().
-- NFSv4: Don't hold the layoutget locks across multiple RPC calls
-- tcp: tcp_rtx_synack() can be called from process context
-- serial: 8250_fintek: Check SER_RS485_RTS_* only with RS485
-- md: fix an incorrect NULL check in md_reload_sb
-- md: fix an incorrect NULL check in does_sb_need_changing
-- ext4: avoid cycles in directory h-tree
-- ext4: verify dir block before splitting it
-- proc: fix dentry/inode overinstantiating under /proc/${pid}/net
-- drivers/base/node.c: fix compaction sysfs file leak
-- fsnotify: fix wrong lockdep annotations
-- PCI: Avoid pci_dev_lock() AB/BA deadlock with sriov_numvfs_store()
-- fat: add ratelimit to fat*_ent_bread()
-- nvme-pci: fix a NULL pointer dereference in nvme_alloc_admin_tags
-- bpf: Enlarge offset check value to INT_MAX in bpf_skb_{load,store}_bytes
-- dm stats: add cond_resched when looping over entries
-- zsmalloc: fix races between asynchronous zspage free and page migration
-- netfilter: conntrack: re-fetch conntrack after insertion
-- assoc_array: Fix BUG_ON during garbage collect
-- net: af_key: check encryption module availability consistency
-- x86/pci/xen: Disable PCI/MSI[-X] masking for XEN_HVM guests
-- net: bridge: Clear offload_fwd_mark when passing frame up bridge interface.
-- ARM: 9197/1: spectre-bhb: fix loop8 sequence for Thumb2
-- ARM: 9196/1: spectre-bhb: enable for Cortex-A15
-- block:Fix kabi broken
-- block: Fix warning in bd_link_disk_holder()
-- block: move the NEED_PART_SCAN flag to struct gendisk
-- block: rename bd_invalidated
-- scsi: hisi_sas: Modify v3 HW I/O processing when SATA_DISK_ERR bit is set and NCQ Error occurs
-- scsi: hisi_sas: enable use_clustering
-- scsi: hisi_sas: Change DMA setup lock timeout to 2.5s
-- x86/speculation/mmio: Print SMT warning
-- KVM: x86/speculation: Disable Fill buffer clear within guests
-- x86/speculation/mmio: Reuse SRBDS mitigation for SBDS
-- x86/speculation/srbds: Update SRBDS mitigation selection
-- x86/speculation/mmio: Add sysfs reporting for Processor MMIO Stale Data
-- x86/speculation/mmio: Enable CPU Fill buffer clearing on idle
-- x86/bugs: Group MDS, TAA & Processor MMIO Stale Data mitigations
-- x86/speculation/mmio: Add mitigation for Processor MMIO Stale Data
-- x86/speculation: Add a common function for MD_CLEAR mitigation update
-- x86/speculation/mmio: Enumerate Processor MMIO Stale Data bug
-- Documentation: Add documentation for Processor MMIO Stale Data
-- x86/cpu: Add another Alder Lake CPU to the Intel family
-- x86/cpu: Add Lakefield, Alder Lake and Rocket Lake models to the to Intel CPU family
-- x86/cpu: Add Jasper Lake to Intel family
-- cpu/speculation: Add prototype for cpu_show_srbds()
-- x86/cpu: Add Elkhart Lake to Intel family
-- block: open accurate iostat account by default
-- block: use "precise_iostat" to switch accurate iostat account
-- block/diskstats: more accurate approximation of io_ticks for slow disks
-- fs-writeback: writeback_sb_inodes：Recalculate 'wrote' according skipped pages
-
-* Tue Jul 05 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2207.1.0.0157
-- ext4: correct the misjudgment in ext4_iget_extra_inode
-- ext4: correct max_inline_xattr_value_size computing
-- ext4: fix use-after-free in ext4_xattr_set_entry
-- ext4: add EXT4_INODE_HAS_XATTR_SPACE macro in xattr.h
-- tracepoint: Add tracepoint_probe_register_may_exist() for BPF tracing
-- swiotlb: skip swiotlb_bounce when orig_addr is zero
-- KVM: x86: Forbid VMM to set SYNIC/STIMER MSRs when SynIC wasn't activated
-- mm/sharepool: Fix using uninitialized sp_flag
-- mm/sharepool: Add a task_struct parameter for sp_get_local_group()
-- mm/sharepool: Don't check the DVPP address space range before merging
-- mm/sharepool: Configure the DVPP range for process
-- mm/sharepool: Introduce SPG_NON_DVPP flag for sp_group_add_task
-- mm/sharepool: Update sp_mapping structure
-- mm/sharepool: Clear the initialization of sp-associated structure for a process
-- mm/sharepool: Unify the memory allocation process
-- mm/sharepool: Use vm_private_data to store the spa
-- mm/sharepool: Share pool statistics adaption
-- mm/sharepool: Release the sp addr based on the id
-- mm/sharepool: Add an interface to obtain an id
-- mm/sharepool: Address space management for sp_group
-- mm/sharepool: Create global normal and dvpp mapping
-- mm/sharepool: Delete single-group mode
-- io_uring: io_close: Set owner as current->files if req->work.files uninitialized
-
-* Mon Jun 27 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2206.4.0.0156
-- mm/memcontrol: fix wrong vmstats for dying memcg
-- ext4: recover csum seed of tmp_inode after migrating to extents
-- xfs: show the proper user quota options
-- drivers core: node: Use a more typical macro definition style for ACCESS_ATTR
-- drivers core: Use sysfs_emit for shared_cpu_map_show and shared_cpu_list_show
-- mm: and drivers core: Convert hugetlb_report_node_meminfo to sysfs_emit
-- drivers core: Miscellaneous changes for sysfs_emit
-- drivers core: Remove strcat uses around sysfs_emit and neaten
-- drivers core: Use sysfs_emit and sysfs_emit_at for show(device *...) functions
-
-* Mon Jun 20 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2206.3.0.0155
-- arm64: fix out-of-range error when adapting for ARM64_SPECTRE_BHB
-- xfs: replace -EIO with -EFSCORRUPTED for corrupt metadata
-- xfs: namecheck directory entry names before listing them
-- xfs: namecheck attribute names before listing them
-- xfs: check attribute leaf block structure
-- xfs: check attribute name validity
-- xfs: check directory name validity
-- xfs: scrub should flag dir/attr offsets that aren't mappable with xfs_dablk_t
-- xfs: abort xattr scrub if fatal signals are pending
-- tcp: increase source port perturb table to 2^16
-- tcp: change source port randomizarion at connect() time
-- arm64: fix extra cpucaps setup problem
-- Revert "sched: Fix sched_fork() access an invalid sched_task_group"
-- Revert "sched: Fix yet more sched_fork() races"
-- powerpc/32: Fix overread/overwrite of thread_struct via ptrace
-- sctp: use call_rcu to free endpoint
-- ext4: convert from atomic_t to refcount_t on ext4_io_end->count
-- ext4: correct the judgment of BUG in ext4_mb_normalize_request
-- ext4: fix bug_on ext4_mb_use_inode_pa
-- HID: holtek: fix mouse probing
-- HID: check for valid USB device for many HID drivers
-- HID: wacom: fix problems when device is not a valid USB device
-- HID: add USB_HID dependancy on some USB HID drivers
-- HID: add USB_HID dependancy to hid-chicony
-- HID: add USB_HID dependancy to hid-prodikeys
-- HID: add hid_is_usb() function to make it simpler for USB detection
-- netfilter: nf_tables: disallow non-stateful expression in sets earlier
-- NFSv4: fix open failure with O_ACCMODE flag
-- Revert "NFSv4: Handle the special Linux file open access mode"
-
-* Mon Jun 13 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2206.2.0.0154
-- x86: Pin task-stack in __get_wchan()
-- x86: Fix __get_wchan() for !STACKTRACE
-- x86/unwind/orc: Fix premature unwind stoppage due to IRET frames
-- x86/unwind: Prevent false warnings for non-current tasks
-- ALSA: pcm: Fix potential AB/BA lock with buffer_mutex and mmap_lock
-- ALSA: pcm: Fix races among concurrent prealloc proc writes
-- ALSA: pcm: Fix races among concurrent prepare and hw_params/hw_free calls
-- ALSA: pcm: Fix races among concurrent read/write and buffer changes
-- ALSA: pcm: Fix races among concurrent hw_params and hw_free calls
-- NFC: netlink: fix sleep in atomic bug when firmware download timeout
-- nfc: replace improper check device_is_registered() in netlink related functions
-- ext4: fix super block checksum incorrect after mount
-- block: remove the bd_openers checks in blk_drop_partitions
-- block: fix busy device checking in blk_drop_partitions again
-- block: fix busy device checking in blk_drop_partitions
-- ext4: add reserved GDT blocks check
-
-* Mon Jun 06 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2206.1.0.0153
-- ping: fix address binding wrt vrf
-- tcp: resalt the secret every 10 seconds
-- netlink: do not reset transport header in netlink_recvmsg()
-- ipv4: drop dst in multicast routing path
-- net: Fix features skip in for_each_netdev_feature()
-- VFS: Fix memory leak caused by concurrently mounting fs with subtype
-- mm: userfaultfd: fix missing cache flush in mcopy_atomic_pte() and __mcopy_atomic()
-- mm: hugetlb: fix missing cache flush in copy_huge_page_from_user()
-- dm: interlock pending dm_io and dm_wait_for_bios_completion
-- dm: fix mempool NULL pointer race when completing IO
-- tcp: make sure treq->af_specific is initialized
-- net: igmp: respect RCU rules in ip_mc_source() and ip_mc_msfilter()
-- x86: __memcpy_flushcache: fix wrong alignment if size > 2^32
-- tcp: fix potential xmit stalls caused by TCP_NOTSENT_LOWAT
-- ip_gre: Make o_seqno start from 0 in native mode
-- tcp: md5: incorrect tcp_header_len for incoming connections
-- mtd: rawnand: Fix return value check of wait_for_completion_timeout
-- mtd: rawnand: fix ecc parameters for mt7622
-- hex2bin: fix access beyond string end
-- serial: 8250: Correct the clock for EndRun PTP/1588 PCIe device
-- serial: 8250: Also set sticky MCR bits in console restoration
-- ext4: force overhead calculation if the s_overhead_cluster makes no sense
-- ext4: fix overhead calculation to account for the reserved gdt blocks
-- ext4: limit length to bitmap_maxbytes - blocksize in punch_hole
-- arm_pmu: Validate single/group leader events
-- netlink: reset network and mac headers in netlink_dump()
-- net/packet: fix packet_sock xmit return value checking
-- mm: page_alloc: fix building error on -Werror=array-compare
-- etherdevice: Adjust ether_addr* prototypes to silence -Wstringop-overead
-- smp: Fix offline cpu check in flush_smp_call_function_queue()
-- ipv6: fix panic when forwarding a pkt with no in6 dev
-- mm: kmemleak: take a full lowmem check in kmemleak_*_phys()
-- mm, page_alloc: fix build_zonerefs_node()
-- cifs: potential buffer overflow in handling symlinks
-- veth: Ensure eth header is in skb's linear part
-- mm/sparsemem: fix 'mem_section' will never be NULL gcc 12 warning
-- mm: don't skip swap entry even if zap_details specified
-- irqchip/gic-v3: Fix GICR_CTLR.RWP polling
-- mm/mempolicy: fix mpol_new leak in shared_policy_replace
-- mmmremap.c: avoid pointless invalidate_range_start/end on mremap(old_size=0)
-- mm: fix race between MADV_FREE reclaim and blkdev direct IO read
-- NFS: swap-out must always use STABLE writes.
-- NFS: swap IO handling is slightly different for O_DIRECT IO
-- SUNRPC/call_alloc: async tasks mustn't block waiting for memory
-- NFSv4: Protect the state recovery thread against direct reclaim
-- macvtap: advertise link netns via netlink
-- dm ioctl: prevent potential spectre v1 gadget
-- ipv4: Invalidate neighbour for broadcast address upon address addition
-- mm/memcontrol: return 1 from cgroup.memory __setup() handler
-- ACPI: CPPC: Avoid out of bounds access when parsing _CPC data
-- ext4: don't BUG if someone dirty pages without asking ext4 first
-- PM: core: keep irq flags in device_pm_check_callbacks()
-- ACPI/APEI: Limit printable size of BERT table data
-- ACPICA: Avoid walking the ACPI Namespace if it is not there
-- netfilter: nf_conntrack_tcp: preserve liberal flag in tcp options
-- NFS: remove unneeded check in decode_devicenotify_args()
-- serial: 8250: Fix race condition in RTS-after-send handling
-- serial: 8250_mid: Balance reference count for PCI DMA device
-- tcp: ensure PMTU updates are processed during fastopen
-- af_netlink: Fix shift out of bounds in group mask calculation
-- mtd: rawnand: atmel: fix refcount issue in atmel_nand_controller_init
-- mtd: onenand: Check for error irq
-- printk: fix return value of printk.devkmsg __setup handler
-- perf/core: Fix address filter parser for multiple filters
-- ACPI: APEI: fix return value of __setup handlers
-- crypto: authenc - Fix sleep in atomic context in decrypt_tail
-- PCI: pciehp: Clear cmd_busy bit in polling mode
-- ACPI: properties: Consistently return -ENOENT if there are no more references
-- mm,hwpoison: unmap poisoned page before invalidation
-- scsi: libsas: Fix sas_ata_qc_issue() handling of NCQ NON DATA commands
-- mempolicy: mbind_range() set_policy() after vma_merge()
-- mm: invalidate hwpoison page cache page in fault path
-- mm/pages_alloc.c: don't create ZONE_MOVABLE beyond the end of a node
-- NFSD: prevent integer overflow on 32 bit systems
-- SUNRPC: avoid race between mod_timer() and del_timer_sync()
-- xfrm: fix tunnel model fragmentation behavior
-- sched/fair: Fix enqueue_task_fair() warning some more
-- sched/fair: Fix enqueue_task_fair warning
-- floppy: disable FDRAWCMD by default
-- perf: Fix sys_perf_event_open() race against self
-- KVM: x86/mmu: fix NULL pointer dereference on guest INVPCID
-
-* Tue May 31 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2205.6.0.0152
-- net: hns3: update hns3 version to 22.5.1
-- net: hns3: fix vf link setting failed when no vf driver loaded
-- arm64: Add memmap reserve range check to avoid conflict
-- ext4: fix bug_on in ext4_writepages
-- ext4: fix warning in ext4_handle_inode_extension
-- ext4: fix use-after-free in ext4_rename_dir_prepare
-- uce: coredump scenario support kernel recovery
-- NULL pointer dereference on rmmod iptable_mangle.
-
-* Tue May 24 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2205.5.0.0151
-- sched/qos: Add qos_tg_{throttle,unthrottle}_{up,down}
-- sched: Throttle offline task at tracehook_notify_resume()
-- sched: enable CONFIG_QOS_SCHED on arm64
-- sched/qos: Remove dependency CONFIG_x86
-- net/sched: cls_u32: fix netns refcount changes in u32_change()
-- mm: hwpoison: enable memory error handling on 1GB hugepage optionaly
-- mm: fix gup_pud_range
-- nfc: nfcmrvl: main: reorder destructive operations in nfcmrvl_nci_unregister_dev to avoid bugs
-- ext4: fix warning when submitting superblock in ext4_commit_super()
-- ext4: fix bug_on in __es_tree_search
-- secure_seq: use the 64 bits of the siphash for port offset calculation
-- floppy: use a statically allocated error counter
-- mmc: block: fix read single on recovery logic
-- SUNRPC: Ensure that the gssproxy client can start in a connected state
-- Revert "SUNRPC: attempt AF_LOCAL connect on setup"
-- ax25: Fix UAF bugs in ax25 timers
-- ptrace: Check PTRACE_O_SUSPEND_SECCOMP permission on PTRACE_SEIZE
-- drm/vgem: Close use-after-free race in vgem_gem_create
-- mm/memory.c: update the first page in clear_gigantic_page_chunk
-
-* Tue May 17 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2205.4.0.0150
-- scsi: hisi_sas: Change hisi_sas_control_phy() phyup timeout
-- scsi: hisi_sas: Fix SAS disk sense info print incorrectly sometimes
-- scsi: hisi_sas: Don't fail IT nexus reset for Open Reject timeout
-- mm/share_pool: Support read-only memory allocation
-- mm: clear_freelist_page: Provide timeout mechanism for worker runtime
-- io_uring: fix race between timeout flush and removal
-- ax25: fix UAF bug in ax25_send_control()
-- ax25: Fix refcount leaks caused by ax25_cb_del()
-- ax25: fix UAF bugs of net_device caused by rebinding operation
-- ax25: fix reference count leaks of ax25_dev
-- ax25: add refcount in ax25_dev to avoid UAF bugs
-- ext4: fix bug_on in start_this_handle during umount filesystem
-- ext4: unregister sysfs path before destroying jbd2 journal
-- ext4: fix use-after-free in ext4_search_dir
-- mm: Update reliable flag in memory allocaion for reliable task only in task context
-- mm: refactor the reclaim thread of page cache from per-cpu to per-node
-
-* Tue May 10 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2205.3.0.0149
-- ixgbevf: add disable link state
-- ixgbe: add improvement for MDD response functionality
-- ixgbe: add the ability for the PF to disable VF link state
-- io_uring: fix false WARN_ONCE
-- mm/sharepool: Fix sharepool node id invalid when using sp_alloc
-- sharepool: fix hisi oom deadlock
-- share_pool: Fix ABBA deadlock
-- net: ipv6: fix skb_over_panic in __ip6_append_data
-- net: handle ARPHRD_PIMREG in dev_is_mac_header_xmit()
-- net/packet: fix slab-out-of-bounds access in packet_recvmsg()
-- mm: fix dereference a null pointer in migrate[_huge]_page_move_mapping()
-- cpuset: Fix unsafe lock order between cpuset lock and cpuslock
-- tcp: make tcp_read_sock() more robust
-- xfrm: Fix xfrm migrate issues when address family changes
-- Revert "xfrm: state and policy should fail if XFRMA_IF_ID 0"
-- ext4: add check to prevent attempting to resize an fs with sparse_super2
-- net-sysfs: add check for netdevice being present to speed_show
-- memfd: fix F_SEAL_WRITE after shmem huge page allocated
-- PCI: pciehp: Fix infinite loop in IRQ handler upon power fault
-- netfilter: nf_queue: fix possible use-after-free
-- netfilter: nf_queue: don't assume sk is full socket
-- xfrm: enforce validity of offload input flags
-- xfrm: fix the if_id check in changelink
-- netfilter: fix use-after-free in __nf_register_net_hook()
-- xfrm: fix MTU regression
-- cifs: fix double free race when mount fails in cifs_get_root()
-- mtd: rawnand: brcmnand: Fixed incorrect sub-page ECC status
-- x86/asm: Move native_write_cr0/4() out of line
-- x86/asm: Pin sensitive CR0 bits
-- x86/asm: Pin sensitive CR4 bits
-- mm: Add more debug info if oom occurs
-- mm: Fix reliable task used problem shown in meminfo
-- mm: Show correct reliable pagecache size
-
-* Fri May 06 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2205.1.0.0148
-- hamradio: improve the incomplete fix to avoid NPD
-- hamradio: defer ax25 kfree after unregister_netdev
-- can: mcba_usb: mcba_usb_start_xmit(): fix double dev_kfree_skb in error path
-- llc: only change llc->dev when bind() succeeds
-- netdevice: add the case if dev is NULL
-- llc: fix netdevice reference leaks in llc_ui_bind()
-- ARM: fix Thumb2 regression with Spectre BHB
-- ARM: Spectre-BHB: provide empty stub for non-config
-- ARM: fix build warning in proc-v7-bugs.c
-- ARM: Do not use NOCROSSREFS directive with ld.lld
-- ARM: fix co-processor register typo
-- ARM: fix build error when BPF_SYSCALL is disabled
-- ARM: include unprivileged BPF status in Spectre V2 reporting
-- ARM: Spectre-BHB workaround
-- ARM: use LOADADDR() to get load address of sections
-- ARM: early traps initialisation
-- ARM: report Spectre v2 status through sysfs
-- can: usb_8dev: usb_8dev_start_xmit(): fix double dev_kfree_skb() in error path
-
-* Tue Apr 26 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2204.4.0.0147
-- Revert "perf: Paper over the hw.target problems"
-- ax25: Fix NULL pointer dereferences in ax25 timers
-- ax25: fix NPD bug in ax25_disconnect
-- ax25: Fix NULL pointer dereference in ax25_kill_by_device
-- ax25: improve the incomplete fix to avoid UAF and NPD bugs
-- ax25: NPD bug when detaching AX25 device
-- objtool: Fix stack offset tracking for indirect CFAs
-- x86/entry/64: Fix unwind hints in kernel exit path
-- af_key: add __GFP_ZERO flag for compose_sadb_supported in function pfkey_register
-- arm64: Use the clearbhb instruction in mitigations
-- arm64: add ID_AA64ISAR2_EL1 sys register
-- KVM: arm64: Allow SMCCC_ARCH_WORKAROUND_3 to be discovered and migrated
-- arm64: Mitigate spectre style branch history side channels
-- KVM: arm64: Add templates for BHB mitigation sequences
-- arm64: proton-pack: Report Spectre-BHB vulnerabilities as part of Spectre-v2
-- arm64: Add percpu vectors for EL1
-- arm64: entry: Add macro for reading symbol addresses from the trampoline
-- arm64: entry: Add vectors that have the bhb mitigation sequences
-- arm64: entry: Add non-kpti __bp_harden_el1_vectors for mitigations
-- arm64: entry: Allow the trampoline text to occupy multiple pages
-- arm64: entry: Make the kpti trampoline's kpti sequence optional
-- arm64: entry: Move trampoline macros out of ifdef'd section
-- arm64: entry: Don't assume tramp_vectors is the start of the vectors
-- arm64: entry: Allow tramp_alias to access symbols after the 4K boundary
-- arm64: entry: Move the trampoline data page before the text page
-- arm64: entry: Free up another register on kpti's tramp_exit path
-- arm64: entry: Make the trampoline cleanup optional
-- arm64: entry.S: Add ventry overflow sanity checks
-- x86/speculation: Warn about eIBRS + LFENCE + Unprivileged eBPF + SMT
-- x86/speculation: Warn about Spectre v2 LFENCE mitigation
-- x86/speculation: Update link to AMD speculation whitepaper
-- x86/speculation: Use generic retpoline by default on AMD
-- x86/speculation: Include unprivileged eBPF status in Spectre v2 mitigation reporting
-- Documentation/hw-vuln: Update spectre doc
-- x86/speculation: Add eIBRS + Retpoline options
-- x86/speculation: Rename RETPOLINE_AMD to RETPOLINE_LFENCE
-- x86,bugs: Unconditionally allow spectre_v2=retpoline,amd
-- x86/speculation: Merge one test in spectre_v2_user_select_mitigation()
-- mm/memory.c: fix clear_gigantic_page_chunk
-
-* Tue Apr 19 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2204.3.0.0146
-- ext4: fix fs corruption when tring to remove a non-empty directory with IO error
-- Revert "ext4: fix file system corrupted when rmdir non empty directory with IO error"
-- sched: Fix yet more sched_fork() races
-- sched/fair: Fix wrong cpu selecting from isolated domain
-- netfilter: nf_tables: initialize registers in nft_do_chain()
-- nbd: fix possible overflow on 'first_minor' in nbd_dev_add()
-- net: sched: adapt Qdisc kabi
-- net_sched: fix a crash in tc_new_tfilter()
-- net: sched: use Qdisc rcu API instead of relying on rtnl lock
-- net: sched: add helper function to take reference to Qdisc
-- net: sched: extend Qdisc with rcu
-- net: core: netlink: add helper refcount dec and lock function
-- xen/netfront: react properly to failing gnttab_end_foreign_access_ref()
-- xen/gnttab: fix gnttab_end_foreign_access() without page specified
-- xen/pvcalls: use alloc/free_pages_exact()
-- xen/9p: use alloc/free_pages_exact()
-- xen: remove gnttab_query_foreign_access()
-- xen/gntalloc: don't use gnttab_query_foreign_access()
-- xen/scsifront: don't use gnttab_query_foreign_access() for mapped status
-- xen/netfront: don't use gnttab_query_foreign_access() for mapped status
-- xen/blkfront: don't use gnttab_query_foreign_access() for mapped status
-- xen/grant-table: add gnttab_try_end_foreign_access()
-- xen/xenbus: don't let xenbus_grant_ring() remove grants in error case
-- xen/xenbus: Fix granting of vmalloc'd memory
-- binder: fix test regression due to sender_euid change
-- binder: use cred instead of task for selinux checks
-- binder: use euid from cred instead of using task
-- svm: Change svm to modules
-- svm: Delete unused svm_get_unmapped_area ops
-- ascend: mm: Add MAP_ALIGN flag to map aligned va
-- svm: Delete unused function sysrq_sched_debug_show_export
-- svm: Delete get meminfo interface in svm ioctl
-- svm: Export symbols for svm module
-- can: ems_usb: ems_usb_start_xmit(): fix double dev_kfree_skb() in error path
-- mm: Add space after ReliableFileCache
-- mm: Drop reliable_reserve_size
-- mm: page_counter: mitigate consequences of a page_counter underflow
-- drivers: hamradio: 6pack: fix UAF bug caused by mod_timer()
-- hamradio: remove needs_free_netdev to avoid UAF
-- hamradio: defer 6pack kfree after unregister_netdev
-- ovl: fix uninitialized pointer read in ovl_lookup_real_one()
-- ovl: fix IOCB_DIRECT if underlying fs doesn't support direct IO
-- ovl: fix lseek overflow on 32bit
-- ovl: sync dirty data when remounting to ro mode
-
-* Tue Apr 12 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2204.2.0.0145
-- Revert "module, async: async_synchronize_full() on module init iff async is used"
-- tty: n_gsm: fix encoding of control signal octet bit DV
-- fget: clarify and improve __fget_files() implementation
-- memblock: use kfree() to release kmalloced memblock regions
-- tty: n_gsm: fix proper link termination after failed open
-- gso: do not skip outer ip header in case of ipip and net_failover
-- net: __pskb_pull_tail() & pskb_carve_frag_list() drop_monitor friends
-- cgroup/cpuset: Fix a race between cpuset_attach() and cpu hotplug
-- tracing: Fix tp_printk option related with tp_printk_stop_on_boot
-- dmaengine: sh: rcar-dmac: Check for error num after setting mask
-- net: sched: limit TC_ACT_REPEAT loops
-- mtd: rawnand: qcom: Fix clock sequencing in qcom_nandc_probe()
-- NFS: Do not report writeback errors in nfs_getattr()
-- NFS: LOOKUP_DIRECTORY is also ok with symlinks
-- bonding: fix data-races around agg_select_timer
-- drop_monitor: fix data-race in dropmon_net_event / trace_napi_poll_hit
-- ping: fix the dif and sdif check in ping_lookup
-- taskstats: Cleanup the use of task->exit_code
-- xfrm: Don't accidentally set RTO_ONLINK in decode_session4()
-- nvme: fix a possible use-after-free in controller reset during load
-- quota: make dquot_quota_sync return errors from ->sync_fs
-- vfs: make freeze_super abort when sync_filesystem returns error
-- serial: parisc: GSC: fix build when IOSAPIC is not set
-- perf: Fix list corruption in perf_cgroup_switch()
-- seccomp: Invalidate seccomp mode to catch death failures
-- n_tty: wake up poll(POLLRDNORM) on receiving data
-- veth: fix races around rq->rx_notify_masked
-- net: fix a memleak when uncloning an skb dst and its metadata
-- net: do not keep the dst cache when uncloning an skb dst and its metadata
-- ipmr,ip6mr: acquire RTNL before calling ip[6]mr_free_table() on failure path
-- bonding: pair enable_port with slave_arr_updates
-- bpf: Add kconfig knob for disabling unpriv bpf by default
-- scsi: target: iscsi: Make sure the np under each tpg is unique
-- NFSv4 expose nfs_parse_server_name function
-- NFSv4 remove zero number of fs_locations entries error check
-- NFSv4.1: Fix uninitialised variable in devicenotify
-- nfs: nfs4clinet: check the return value of kstrdup()
-- NFSv4 only print the label when its queried
-- NFS: Fix initialisation of nfs_client cl_flags field
-- ima: Allow template selection with ima_template[_fmt]= after ima_hash=
-- ima: Remove ima_policy file before directory
-- integrity: check the return value of audit_log_start()
-- ext4: fix error handling in ext4_restore_inline_data()
-- iommu/amd: Fix loop timeout issue in iommu_ga_log_enable()
-- iommu/vt-d: Fix potential memory leak in intel_setup_irq_remapping()
-- block: bio-integrity: Advance seed correctly for larger interval sizes
-- af_packet: fix data-race in packet_setsockopt / packet_setsockopt
-- rtnetlink: make sure to refresh master_dev/m_ops in __rtnl_newlink()
-- ipv4: tcp: send zero IPID in SYNACK messages
-- ipv4: raw: lock the socket in raw_bind()
-- phylib: fix potential use-after-free
-- NFS: Ensure the server has an up to date ctime before renaming
-- NFS: Ensure the server has an up to date ctime before hardlinking
-- ipv6: annotate accesses to fn->fn_sernum
-- ipv4: avoid using shared IP generator for connected sockets
-- ping: fix the sk_bound_dev_if match in ping_lookup
-- ipv6_tunnel: Rate limit warning messages
-- tty: n_gsm: fix SW flow control encoding/handling
-- serial: stm32: fix software flow control transfer
-- serial: 8250: of: Fix mapped region size when using reg-offset property
-- netfilter: nft_payload: do not update layer 4 checksum when mangling fragments
-- PM: wakeup: simplify the output logic of pm_show_wakelocks()
-- tty: fix crash in release_tty if tty->port is not set
-- tty: don't crash in tty_init_dev when missing tty_port
-- printk: Convert a use of sprintf to snprintf in console_unlock
-
-* Thu Apr 07 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2204.1.0.0144
-- serial: 8250: Fix max baud limit in generic 8250 port
-- sched/fair: Add qos_throttle_list node in struct cfs_rq
-- Reinstate some of "swiotlb: rework "fix info leak with DMA_FROM_DEVICE""
-- Revert "swiotlb: rework "fix info leak with DMA_FROM_DEVICE""
-- USB: gadget: validate endpoint index for xilinx udc
-- sr9700: sanity check for packet length
-- ima: Fix return value of ima_write_policy()
-- ima: Don't modify file descriptor mode on the fly
-- ima: Set file->f_mode instead of file->f_flags in ima_calc_file_hash()
-- ima: Remove __init annotation from ima_pcrread()
-- ima: Call ima_calc_boot_aggregate() in ima_eventdigest_init()
-- evm: Check size of security.evm before using it
-- ima: Don't ignore errors from crypto_shash_update()
-- mm: Fallback to non-mirrored region below low watermark
-- mm: Disable watermark check if reliable fallback is disabled
-- mm: Do limit checking after memory allocation for memory reliable
-
-* Tue Mar 29 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2203.5.0.0143
-- livepatch/arm64: Fix incorrect endian conversion when long jump
-- arm64/mpam: realign step entry when traversing rmid_transform
-- dt-bindings: mpam: refactor device tree node structure
-- arm64/mpam: refactor device tree structure to support multiple devices
-- arm64/mpam: fix __mpam_device_create() section mismatch error
-- block-map: add __GFP_ZERO flag for alloc_page in function bio_copy_kern
-- hugetlb: Add huge page alloced limit
-- swiotlb: rework "fix info leak with DMA_FROM_DEVICE"
-- swiotlb: fix info leak with DMA_FROM_DEVICE
-- esp: Fix possible buffer overflow in ESP transformation
-- sock: remove one redundant SKB_FRAG_PAGE_ORDER macro
-- io_uring: fix UAF in get_files_struct()
-- xfs: fix an undefined behaviour in _da3_path_shift
-- xfs: Fix possible null-pointer dereferences in xchk_da_btree_block_check_sibling()
-- xfs: fix use after free in buf log item unlock assert
-- ACPI/IORT: Do not blindly trust DMA masks from firmware
-
-* Tue Mar 22 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2203.4.0.0142
-- kabi: fix kabi broken in struct fuse_in
-- fuse: fix pipe buffer lifetime for direct_io
-- blk-throtl: fix race in io dispatching
-- ext4: Fix symlink file size not match to file content
-- livepatch/core: Check klp_func before 'klp_init_object_loaded'
-- irqchip/gic-phytium-2500: Fix issue that interrupts are concentrated in one cpu
-- blk-mq: add exception handling when srcu->sda alloc failed
-- audit: improve audit queue handling when "audit=1" on cmdline
-- Revert "audit: bugfix for infinite loop when flush the hold queue"
-- veth: Do not record rx queue hint in veth_xmit
-
-* Tue Mar 15 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2203.3.0.0141
-- crypto: pcrypt - Fix user-after-free on module unload
-- lib/iov_iter: initialize "flags" in new pipe_buffer
-- mm: Count reliable shmem used based on NR_SHMEM
-- mm: fix zoneref mapping problem in memory reliable
-- mm: disable memory reliable when kdump is in progress
-- mm: introduce "clear_freelist" kernel parameter
-- mm: fix unable to use reliable memory in page cache
-- nfc: st21nfca: Fix potential buffer overflows in EVT_TRANSACTION
-- select: Fix indefinitely sleeping task in poll_schedule_timeout()
-- mtd: nand: bbt: Fix corner case in bad block table handling
-- netns: add schedule point in ops_exit_list()
-- af_unix: annote lockless accesses to unix_tot_inflight & gc_in_progress
-- crypto: stm32/crc32 - Fix kernel BUG triggered in probe()
-- ext4: don't use the orphan list when migrating an inode
-- ext4: set csum seed in tmp inode while migrating to extents
-- ext4: make sure quota gets properly shutdown on error
-- ext4: make sure to reset inode lockdep class when quota enabling fails
-- cputime, cpuacct: Include guest time in user time in cpuacct.stat
-- serial: Fix incorrect rs485 polarity on uart open
-- scsi: sr: Don't use GFP_DMA
-- dm space map common: add bounds check to sm_ll_lookup_bitmap()
-- dm btree: add a defensive bounds check to insert_at()
-- ACPICA: Executer: Fix the REFCLASS_REFOF case in acpi_ex_opcode_1A_0T_1R()
-- ACPICA: Utilities: Avoid deleting the same object twice in a row
-- jffs2: GC deadlock reading a page that is used in jffs2_write_begin()
-- bpf: Do not WARN in bpf_warn_invalid_xdp_action()
-- net: bonding: debug: avoid printing debug logs when bond is not notifying peers
-- net-sysfs: update the queue counts in the unregistration path
-- dmaengine: pxa/mmp: stop referencing config->slave_id
-- scsi: ufs: Fix race conditions related to driver data
-- iommu/io-pgtable-arm: Fix table descriptor paddr formatting
-- ext4: avoid trim error on fs with small groups
-- net: mcs7830: handle usb read errors properly
-- tpm: add request_locality before write TPM_INT_ENABLE
-- netfilter: ipt_CLUSTERIP: fix refcount leak in clusterip_tg_check()
-- xfrm: state and policy should fail if XFRMA_IF_ID 0
-- xfrm: interface with if_id 0 should return error
-- crypto: stm32/cryp - fix double pm exit
-- xfrm: fix a small bug in xfrm_sa_len()
-- sched/rt: Try to restart rt period timer when rt runtime exceeded
-- serial: amba-pl011: do not request memory region twice
-- tty: serial: uartlite: allow 64 bit address
-- netfilter: bridge: add support for pppoe filtering
-- crypto: qce - fix uaf on qce_ahash_register_one
-- shmem: fix a race between shmem_unused_huge_shrink and shmem_evict_inode
-- can: bcm: switch timer to HRTIMER_MODE_SOFT and remove hrtimer_tasklet
-- ip6_vti: initialize __ip6_tnl_parm struct in vti6_siocdevprivate
-- scsi: libiscsi: Fix UAF in iscsi_conn_get_param()/iscsi_conn_teardown()
-- ipv6: Do cleanup if attribute validation fails in multipath route
-- ipv6: Continue processing multipath route even if gateway attribute is invalid
-- ipv6: Check attribute length for RTA_GATEWAY when deleting multipath route
-- ipv6: Check attribute length for RTA_GATEWAY in multipath route
-- tracing: Tag trace_percpu_buffer as a percpu pointer
-- tracing: Fix check for trace_percpu_buffer validity in get_trace_buf()
-- net: fix use-after-free in tw_timer_handler
-- udp: using datalen to cap ipv6 udp max gso segments
-- selinux: initialize proto variable in selinux_ip_postroute_compat()
-- x86/pkey: Fix undefined behaviour with PKRU_WD_BIT
-- ipmi: fix initialization when workqueue allocation fails
-- ipmi: bail out if init_srcu_struct fails
-- bonding: fix ad_actor_system option setting to default
-- ipmi: Fix UAF when uninstall ipmi_si and ipmi_msghandler module
-- net: skip virtio_net_hdr_set_proto if protocol already set
-- net: hns3: update hns3 version to 22.2.1
-- net: hns3: fix RMW issue for VLAN filter switch
-- net: hns3: fix pf vlan filter out of work after self test
-- arm64: acpi: fix UBSAN warning
-- sched: Fix sleeping in atomic context at cpu_qos_write()
-- io_uring: don't re-setup vecs/iter in io_resumit_prep() is already there
-- io_uring: don't double complete failed reissue request
-- io_uring: remove redundant initialization of variable ret
-- block: don't ignore REQ_NOWAIT for direct IO
-- io_uring: re-issue block requests that failed because of resources
-- dm multipath: fix missing blk_account_io_done() in error path
-- block: account inflight from blk_account_io_start() if 'precise_iostat' is set
-- block: add a switch for precise iostat accounting
-- blk-throttle: Set BIO_THROTTLED when bio has been throttled
-- bfq: fix use-after-free in bfq_dispatch_request
-- hugetlbfs: fix a truncation issue in hugepages parameter
-
-* Tue Mar 08 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2203.2.0.0140
-- mm: Fix return val in khugepaged_scan_pmd()
-- mm: do some clean up of accounting ReliableTaskUsed
-- mm: fix statistic of ReliableTaskUsed
-- mm: fix missing reclaim of low-reliable page cache
-- mm: fix statistic of ReliableFileCache in /proc/meminfo
-- mm: Add more gfp flag check in prepare_before_alloc()
-- efi: Stub mirrored_kernelcore if CONFIG_HAVE_MEMBLOCK_NODE_MAP is not enabled
-- mm: Memory reliable features can only be disabled via proc interface
-- mm: Fix reliable_debug in proc not consistent with boot parameter problem
-- f2fs: fix to do sanity check on inode type during garbage collection
-- mm: Check page status in page_reliable()
-- mm: Show ReliableTaskUsed in /proc/meminfo
-- mm: Refactor code in reliable_report_meminfo()
-- mm: Show correct reliable_user_used if PAGE_SIZE is not 4K
-- proc: Fix reliable display err in /proc/pid/status
-- Revert "mm: add page cache fallback statistic"
-- mm: fix page cache use reliable memory when reliable_debug=P
-- mm: add support for limiting the usage of reliable memory in pagecache
-- mm: add "ReliableFileCache" item in /proc/meminfo
-- mm: Introduce shmem mirrored memory limit for memory reliable
-- mm: Introduce watermark check for memory reliable
-- mm: Count mirrored pages in buddy system
-- mm: Export mem_reliable_status() for checking memory reliable status
-- mm: Make MEMORY_RELIABLE depends on HAVE_MEMBLOCK_NODE_MAP
-- efi: Disable mirror feature if kernelcore is not spcified
-- mm: Introduce proc interface to control memory reliable features
-- mm: Demote warning message in vmemmap_verify() to debug level
-- mm: Ratelimited mirrored memory related warning messages
-
-* Tue Mar 01 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2203.1.0.0139
-- usb: gadget: rndis: check size of RNDIS_MSG_SET command
-- USB: gadget: validate interface OS descriptor requests
-- mm/hwpoison: clear MF_COUNT_INCREASED before retrying get_any_page()
-- udf: Restore i_lenAlloc when inode expansion fails
-- udf: Fix NULL ptr deref when converting from inline format
-- ext4: fix underflow in ext4_max_bitmap_size()
-- bpf: Verifer, adjust_scalar_min_max_vals to always call update_reg_bounds()
-- livepatch/x86: Fix incorrect use of 'strncpy'
-- tipc: improve size validations for received domain records
-- yam: fix a memory leak in yam_siocdevprivate()
-- ipmi_si: Phytium S2500 missing timeout counter reset in intf_mem_inw
-- mm,hwpoison: Fix use-after-free in memory_failure()
-- dm-mpath: fix UAF in multipath_message()
-- usb: gadget: clear related members when goto fail
-- usb: gadget: don't release an existing dev->buf
-- dm: make sure dm_table is binded before queue request
-- cgroup-v1: Require capabilities to set release_agent
-- NFSv4: nfs_atomic_open() can race when looking up a non-regular file
-- NFSv4: Handle case where the lookup of a directory fails
-- configfs: fix a race in configfs_{,un}register_subsystem()
-
-* Tue Feb 22 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2202.4.0.0138
-- tipc: improve size validations for received domain records
-- yam: fix a memory leak in yam_siocdevprivate()
-- ipmi_si: Phytium S2500 missing timeout counter reset in intf_mem_inw
-- mm,hwpoison: Fix use-after-free in memory_failure()
-- dm-mpath: fix UAF in multipath_message()
-- usb: gadget: clear related members when goto fail
-- usb: gadget: don't release an existing dev->buf
-- dm: make sure dm_table is binded before queue request
-- cgroup-v1: Require capabilities to set release_agent
-- NFSv4: nfs_atomic_open() can race when looking up a non-regular file
-- NFSv4: Handle case where the lookup of a directory fails
-- configfs: fix a race in configfs_{,un}register_subsystem()
-- fs/filesystems.c: downgrade user-reachable WARN_ONCE() to pr_warn_once()
-- drm/i915: Flush TLBs before releasing backing store
-- moxart: fix potential use-after-free on remove path
-- memstick: rtsx_usb_ms: fix UAF
-
-* Tue Feb 15 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2202.3.0.0137
-- fs/filesystems.c: downgrade user-reachable WARN_ONCE() to pr_warn_once()
-- drm/i915: Flush TLBs before releasing backing store
-- moxart: fix potential use-after-free on remove path
-- memstick: rtsx_usb_ms: fix UAF
-- ext4: fix file system corrupted when rmdir non empty directory with IO error
-- bpf, doc: Remove references to warning message when using bpf_trace_printk()
-- bpf: Remove inline from bpf_do_trace_printk
-- bpf: Use dedicated bpf_trace_printk event instead of trace_printk()
-- net: cipso: fix warnings in netlbl_cipsov4_add_std
-- xsk: Use struct_size() helper
-- mm/page_alloc: fix counting of free pages after take off from buddy
-- mm,hwpoison: drop unneeded pcplist draining
-- mm,hwpoison: take free pages off the buddy freelists
-- mm,hwpoison: drain pcplists before bailing out for non-buddy zero-refcount page
-- mm,hwpoison: Try to narrow window race for free pages
-- mm,hwpoison: introduce MF_MSG_UNSPLIT_THP
-- mm,hwpoison: return 0 if the page is already poisoned in soft-offline
-- mm,hwpoison: refactor soft_offline_huge_page and __soft_offline_page
-- mm,hwpoison: rework soft offline for in-use pages
-- mm,hwpoison: rework soft offline for free pages
-- mm,hwpoison: unify THP handling for hard and soft offline
-- mm,hwpoison: kill put_hwpoison_page
-- mm,hwpoison: refactor madvise_inject_error
-- mm,hwpoison-inject: don't pin for hwpoison_filter
-- mm, hwpoison: remove recalculating hpage
-- mm,hwpoison: cleanup unused PageHuge() check
-- scsi: Revert "target: iscsi: Wait for all commands to finish before freeing a session"
-- uce: get_user scenario support kernel recovery
-- uce: copy_from_user scenario support kernel recovery
-- mm: Modify sharepool sp_mmap() page_offset
-- support multiple node for getting phys interface
-- share_pool: Accept device_id in k2u flags
-- share_pool: Clear the usage of node_id and device_id
-- share_pool: Make multi-device support extendable
-- share_pool: Fix flags conflict
-- config: enable MEMORY_RELIABLE by default
-- mm: add sysctl to clear free list pages
-- workqueue: Provide queue_work_node to queue work near a given NUMA node
-- mm:vmscan: add the missing check of page_cache_over_limit
-- sysctl: add proc interface to set page cache limit
-- mm/vmscan: dont do shrink_slab in reclaim page cache
-- mm/vmscan: dont reclaim anon page when shrink page cache
-- filemap: dont shrink_page_cache in add_to_page_cache
-- mm/vmscan: fix unexpected shrinking page cache with vm_cache_reclaim_enable disable
-- mm/vmscan: fix frequent call of shrink_page_cache_work
-- proc/meminfo: add "FileCache" item in /proc/meminfo
-- mm: add page cache fallback statistic
-- mm: add cmdline for the reliable memory usage of page cache
-- mm: make page cache use reliable memory by default
-- shmem: Show reliable shmem info
-- shmem: Introduce shmem reliable
-- mm: Introduce fallback mechanism for memory reliable
-- mm: Add reliable memory use limit for user tasks
-- mm: thp: Add memory reliable support for hugepaged collapse
-- proc: Count reliable memory usage of reliable tasks
-- mm: Add reliable_nr_page for accounting reliable memory
-- mm: Introduce reliable flag for user task
-- meminfo: Show reliable memory info
-- mm: Introduce memory reliable
-- efi: Find mirrored memory ranges for arm64
-- efi: Make efi_find_mirror() public
-- arm64: efi: Add fake memory support
-- efi: Make efi_print_memmap() public
-- mm/memory_hotplug: allow to specify a default online_type
-- mm/memory_hotplug: convert memhp_auto_online to store an online_type
-- hv_balloon: don't check for memhp_auto_online manually
-- drivers/base/memory: store mapping between MMOP_* and string in an array
-- drivers/base/memory: map MMOP_OFFLINE to 0
-- drivers/base/memory: rename MMOP_ONLINE_KEEP to MMOP_ONLINE
-- drivers/base/memory.c: Use DEVICE_ATTR_RO and friends
-- mm/memory_hotplug: drop "online" parameter from add_memory_resource()
-
-* Tue Feb 08 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2202.1.0.0136
-- config: enable CONFIG_MEMCG_MEMFS_INFO by default
-- mm/memcg_memfs_info: show files that having pages charged in mem_cgroup
-- ext4: fix e2fsprogs checksum failure for mounted filesystem
-- drm/vmwgfx: Fix stale file descriptors on failed usercopy
-- perf vendor events amd: Fix broken L2 Cache Hits from L2 HWPF metric
-- perf vendor events amd: Add recommended events
-- perf vendor events amd: Add L2 Prefetch events for zen1
-- perf/amd/uncore: Fix sysfs type mismatch
-- perf/x86/amd: Don't touch the AMD64_EVENTSEL_HOSTONLY bit inside the guest
-- tools/power turbostat: Support AMD Family 19h
-- perf/x86/amd/ibs: Support 27-bit extended Op/cycle counter
-- perf vendor events amd: Enable Family 19h users by matching Zen2 events
-- perf vendor events amd: Update Zen1 events to V2
-- perf vendor events amd: Add Zen2 events
-- perf vendor events amd: Restrict model detection for zen1 based processors
-- perf vendor events amd: Remove redundant '['
-- perf vendor events intel: Add Tremontx event file v1.02
-- perf vendor events intel: Add Icelake V1.00 event file
-- perf vendor events amd: Add L3 cache events for Family 17h
-- perf vendor events intel: Add uncore_upi JSON support
-- perf vendor events amd: perf PMU events for AMD Family 17h
-- perf/amd/uncore: Allow F19h user coreid, threadmask, and sliceid specification
-- perf/amd/uncore: Allow F17h user threadmask and slicemask specification
-- perf/amd/uncore: Prepare to scale for more attributes that vary per family
-- perf/x86/amd/ibs: Don't include randomized bits in get_ibs_op_count()
-- perf/amd/uncore: Set all slices and threads to restore perf stat -a behaviour
-- perf/x86/amd/ibs: Fix raw sample data accumulation
-- arch/x86/amd/ibs: Fix re-arming IBS Fetch
-- perf/amd/uncore: Add support for Family 19h L3 PMU
-- perf/amd/uncore: Make L3 thread mask code more readable
-- perf/amd/uncore: Prepare L3 thread mask code for Family 19h
-- EDAC/amd64: Handle three rank interleaving mode
-- EDAC/amd64: Add family ops for Family 19h Models 00h-0Fh
-- EDAC/amd64: Save max number of controllers to family type
-- EDAC/amd64: Gather hardware information early
-- EDAC/amd64: Make struct amd64_family_type global
-- EDAC/amd64: Set grain per DIMM
-- EDAC/amd64: Support asymmetric dual-rank DIMMs
-- EDAC/amd64: Cache secondary Chip Select registers
-- EDAC/amd64: Add PCI device IDs for family 17h, model 70h
-- EDAC/amd64: Find Chip Select memory size using Address Mask
-- EDAC/amd64: Adjust printed chip select sizes when interleaved
-- EDAC/amd64: Recognize x16 symbol size
-- EDAC/amd64: Set maximum channel layer size depending on family
-- EDAC/amd64: Support more than two Unified Memory Controllers
-- EDAC/amd64: Add Family 17h Model 30h PCI IDs
-- EDAC/amd64: Initialize DIMM info for systems with more than two channels
-- EDAC/amd64: Support more than two controllers for chip selects handling
-- EDAC/amd64: Use a macro for iterating over Unified Memory Controllers
-- x86/mce: Fix use of uninitialized MCE message string
-- x86/MCE/AMD, EDAC/mce_amd: Add new Load Store unit McaType
-- x86/MCE/AMD, EDAC/mce_amd: Add new error descriptions for some SMCA bank types
-- x86/MCE/AMD, EDAC/mce_amd: Add new McaTypes for CS, PSP, and SMU units
-- x86/MCE/AMD, EDAC/mce_amd: Add new MP5, NBIO, and PCIE SMCA bank types
-- EDAC/mce_amd: Always load on SMCA systems
-- x86/cpu/amd: Call init_amd_zn() om Family 19h processors too
-- x86/amd_nb: Add Family 19h PCI IDs
-- x86/amd_nb: Add PCI device IDs for family 17h, model 70h
-- x86/amd_nb: Add PCI device IDs for family 17h, model 30h
-- hwmon/k10temp, x86/amd_nb: Consolidate shared device IDs
-- EDAC/amd64: Drop some family checks for newer systems
-- x86/microcode/AMD: Increase microcode PATCH_MAX_SIZE
-- KVM: mmu: Fix SPTE encoding of MMIO generation upper half
-- build_bug.h: add wrapper for _Static_assert
-- KVM: x86: fix overlap between SPTE_MMIO_MASK and generation
-- KVM: x86: assign two bits to track SPTE kinds
-- KVM: Move the memslot update in-progress flag to bit 63
-- KVM: Remove the hack to trigger memslot generation wraparound
-- KVM: x86: clflushopt should be treated as a no-op by emulation
-- KVM: SVM: Clear the CR4 register on reset
-- KVM: SVM: Replace hard-coded value with #define
-- KVM: x86/mmu: Set mmio_value to '0' if reserved #PF can't be generated
-- KVM: x86/mmu: Apply max PA check for MMIO sptes to 32-bit KVM
-- KVM: x86: only do L1TF workaround on affected processors
-- kvm: x86: Fix L1TF mitigation for shadow MMU
-- KVM: x86/mmu: Consolidate "is MMIO SPTE" code
-- KVM: SVM: Override default MMIO mask if memory encryption is enabled
-- KVM: x86/mmu: Add explicit access mask for MMIO SPTEs
-- kvm: x86: Fix reserved bits related calculation errors caused by MKTME
-- KVM: x86: Rename access permissions cache member in struct kvm_vcpu_arch
-- kvm: x86: Move kvm_set_mmio_spte_mask() from x86.c to mmu.c
-- kvm/svm: PKU not currently supported
-- kvm: x86: Expose RDPID in KVM_GET_SUPPORTED_CPUID
-- KVM: x86: Refactor the MMIO SPTE generation handling
-- KVM: Explicitly define the "memslot update in-progress" bit
-- KVM: x86: Use a u64 when passing the MMIO gen around
-- KVM: x86: expose MOVDIR64B CPU feature into VM.
-- KVM: x86: expose MOVDIRI CPU feature into VM.
-- KVM: x86: Add requisite includes to hyperv.h
-- KVM: x86: Add requisite includes to kvm_cache_regs.h
-- KVM: nVMX: Allocate and configure VM{READ,WRITE} bitmaps iff enable_shadow_vmcs
-- x86/cpufeatures: Enumerate MOVDIR64B instruction
-- x86/cpufeatures: Enumerate MOVDIRI instruction
-- x86/pkeys: Don't check if PKRU is zero before writing it
-- x86/fpu: Only write PKRU if it is different from current
-- x86/pkeys: Provide *pkru() helpers
-- sysctl: returns -EINVAL when a negative value is passed to proc_doulongvec_minmax
-- arm64: move jump_label_init() before parse_early_param()
-- tcp: fix memleak when tcp internal pacing is used
-- scsi: scsi_debug: Sanity check block descriptor length in resp_mode_select()
-- ovl: fix warning in ovl_create_real()
-- fuse: annotate lock in fuse_reverse_inval_entry()
-- PCI/MSI: Clear PCI_MSIX_FLAGS_MASKALL on error
-- sit: do not call ipip6_dev_free() from sit_init_net()
-- net/packet: rx_owner_map depends on pg_vec
-- x86/sme: Explicitly map new EFI memmap table as encrypted
-- dm btree remove: fix use after free in rebalance_children()
-- net: netlink: af_netlink: Prevent empty skb by adding a check on len.
-- irqchip/irq-gic-v3-its.c: Force synchronisation when issuing INVALL
-- net, neigh: clear whole pneigh_entry at alloc time
-- aio: fix use-after-free due to missing POLLFREE handling
-- aio: keep poll requests on waitqueue until completed
-- signalfd: use wake_up_pollfree()
-- wait: add wake_up_pollfree()
-- tracefs: Have new files inherit the ownership of their parent
-- mm: bdi: initialize bdi_min_ratio when bdi is unregistered
-- udp: using datalen to cap max gso segments
-- bpf: Fix the off-by-two error in range markings
-- ipmi: msghandler: Make symbol 'remove_work_wq' static
-- serial: core: fix transmit-buffer reset and memleak
-- serial: pl011: Add ACPI SBSA UART match id
-- net: annotate data-races on txq->xmit_lock_owner
-- ipmi: Move remove_work to dedicated workqueue
-- vrf: Reset IPCB/IP6CB when processing outbound pkts in vrf dev xmit
-- scsi: iscsi: Unblock session then wake up error handler
-- shm: extend forced shm destroy to support objects from several IPC nses
-- fuse: release pipe buf after last use
-- tracing: Check pid filtering when creating events
-- ipv6: fix typos in __ip6_finish_output()
-- proc/vmcore: fix clearing user buffer by properly using clear_user()
-- tracing: Fix pid filtering when triggers are attached
-- fuse: fix page stealing
-- ipmi_si: Phytium S2500 workaround for MMIO-based IPMI
-- etmem: Add a scan flag to support specified page swap-out
-- etmem: add swapcache reclaim to etmem
-- etmem: add original kernel swap enabled options
-
-* Tue Jan 25 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2201.4.0.0135
-- net: bridge: clear bridge's private skb space on xmit
-- audit: bugfix for infinite loop when flush the hold queue
-- blk-throttle: enable hierarchical throttle in cgroup v1
-- xfs: map unwritten blocks in XFS_IOC_{ALLOC,FREE}SP just like fallocate
-
-* Tue Jan 18 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2201.3.0.0134
-- ip_gre: validate csum_start only on pull
-- hugetlbfs: fix issue of preallocation of gigantic pages can't work
-- hugetlbfs: extend the definition of hugepages parameter to support node allocation
-- mm: remove sharepool sp_unshare_uva current->mm NULL check
-- share pool: use rwsem to protect sp group exit
-- Add new module parameters:time out
-- virtio-blk: validate num_queues during probe
-- virtio-blk: Use blk_validate_block_size() to validate block size
-- block: Add a helper to validate the block size
-- Revert "virtio-blk: Add validation for block size in config space"
-- scsi: virtio_scsi: Rescan the entire target on transport reset when LUN is 0
-- Revert "svm: Add support to get svm mpam configuration"
-- Revert "svm: Add support to set svm mpam configuration"
-- Revert "svm: Add svm_set_user_mpam_en to enable/disable mpam for smmu"
-- cgroup: Use open-time cgroup namespace for process migration perm checks
-- cgroup: Allocate cgroup_file_ctx for kernfs_open_file->priv
-- cgroup: Use open-time credentials for process migraton perm checks
-- NFC: add necessary privilege flags in netlink layer
-- NFC: add NCI_UNREG flag to eliminate the race
-- NFC: reorder the logic in nfc_{un,}register_device
-- NFC: reorganize the functions in nci_request
-- ext4: Fix BUG_ON in ext4_bread when write quota data
-- PM: hibernate: use correct mode for swsusp_close()
-- Revert "watchdog: Fix check_preemption_disabled() error"
-
-* Tue Jan 11 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2201.2.0.0133
-- arm64/mpam: fix mpam dts init arm_mpam_of_device_ids error
-- arm64/mpam: fix mpam probe error for wrong init order
-
-* Tue Jan 04 2022 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2201.1.0.0132
-- mm: export collect_procs()
-- net: hns: update hns version to 21.12.1
-- net: hns: fix bug when two ports opened promisc mode both
-- net: hns3: update hns3 version to 21.12.4
-- net: hns3: fix the concurrency between functions reading debugfs
-- f2fs: fix to do sanity check on last xattr entry in __f2fs_setxattr()
-- mwifiex: Fix skb_over_panic in mwifiex_usb_recv()
-- tee: handle lookup of shm with reference count 0
-- tee: don't assign shm id for private shms
-- tee: remove linked list of struct tee_shm
-- ext4: fix an use-after-free issue about data=journal writeback mode
-- ext4: Fix null-ptr-deref in '__ext4_journal_ensure_credits'
-- scsi: ufs: Correct the LUN used in eh_device_reset_handler() callback
-- netdevsim: Zero-initialize memory for new map's value in function nsim_bpf_map_alloc
-- lib/strncpy_from_user.c: Mask out bytes after NUL terminator.
-- bpf: Add probe_read_{user, kernel} and probe_read_{user, kernel}_str helpers
-- bpf: Make use of probe_user_write in probe write helper
-- uaccess: Add strict non-pagefault kernel-space read function
-- bpf: fix script for generating man page on BPF helpers
-- bpf: Backport __BPF_FUNC_MAPPER and annotation from mainline
-- bpf: Fix up register-based shifts in interpreter to silence KUBSAN
-- xen/netback: don't queue unlimited number of packages
-- xen/netback: fix rx queue stall detection
-- xen/console: harden hvc_xen against event channel storms
-- xen/netfront: harden netfront against event channel storms
-- xen/blkfront: harden blkfront against event channel storms
-- xen/netfront: don't trust the backend response data blindly
-- xen/netfront: disentangle tx_skb_freelist
-- xen/netfront: don't read data from request on the ring page
-- xen/netfront: read response from backend only once
-- xen/blkfront: don't trust the backend response data blindly
-- xen/blkfront: don't take local copy of a request from the ring page
-- xen/blkfront: read response from backend only once
-- xen: sync include/xen/interface/io/ring.h with Xen's newest version
-- xen/netback: avoid race in xenvif_rx_ring_slots_available()
-- netfilter: fix regression in looped (broad|multi)cast's MAC handling
-- perf/core: Avoid put_page() when GUP fails
-- perf/core: Disable page faults when getting phys address
-- mm: kmemleak: slob: respect SLAB_NOLEAKTRACE flag
-- ipc: WARN if trying to remove ipc object which is absent
-- tun: fix bonding active backup with arp monitoring
-- perf/x86/intel/uncore: Fix IIO event constraints for Skylake Server
-- perf/x86/intel/uncore: Fix filter_tid mask for CHA events on Skylake Server
-- sched/core: Mitigate race cpus_share_cache()/update_top_cache_domain()
-- tty: tty_buffer: Fix the softlockup issue in flush_to_ldisc
-- PCI/MSI: Deal with devices lying about their MSI mask capability
-- PCI/MSI: Destroy sysfs before freeing entries
-- ext4: fix lazy initialization next schedule time computation in more granular unit
-- x86/cpu: Fix migration safety with X86_BUG_NULL_SEL
-- mm, oom: do not trigger out_of_memory from the #PF
-- mm, oom: pagefault_out_of_memory: don't force global OOM for dying tasks
-- llc: fix out-of-bound array index in llc_sk_dev_hash()
-- zram: off by one in read_block_state()
-- mm/zsmalloc.c: close race window between zs_pool_dec_isolated() and zs_unregister_migration()
-- dmaengine: dmaengine_desc_callback_valid(): Check for `callback_result`
-- netfilter: nfnetlink_queue: fix OOB when mac header was cleared
-- NFS: Fix deadlocks in nfs_scan_commit_list()
-- apparmor: fix error check
-- serial: 8250_dw: Drop wrong use of ACPI_PTR()
-- crypto: pcrypt - Delay write to padata->info
-- tcp: don't free a FIN sk_buff in tcp_remove_empty_skb()
-- cgroup: Make rebind_subsystems() disable v2 controllers all at once
-- task_stack: Fix end_of_stack() for architectures with upwards-growing stack
-- gre/sit: Don't generate link-local addr if addr_gen_mode is IN6_ADDR_GEN_MODE_NONE
-- smackfs: Fix use-after-free in netlbl_catmap_walk()
-- signal: Remove the bogus sigkill_pending in ptrace_stop
-- bpf: Prevent increasing bpf_jit_limit above max
-- x86/sme: Use #define USE_EARLY_PGTABLE_L5 in mem_encrypt_identity.c
-- tpm: Check for integer overflow in tpm2_map_response_body()
-- scsi: core: Put LLD module refcnt after SCSI device is released
-- net: Prevent infinite while loop in skb_tx_hash()
+* Mon Oct 24 2022 Jiachen Fan <fanjiachen3@huawei.com> - 4.19.90-2112.8.0.0132
+- poc perfomance's fix for kernel
 
 * Thu Dec 30 2021 Laibin Qiu <qiulaibin@huawei.com> - 4.19.90-2112.8.0.0131
 - mm/page_alloc: Use cmdline to disable "place pages to tail"
Binary files kernel/kernel.tar.gz and obs_kernel/kernel.tar.gz differ
